<?php
/*
 * Created by Artureanec
*/

namespace Cosmecos\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Image_Size;
use Elementor\REPEATER;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Cosmecos_Blog_Listing_Widget extends Widget_Base {

    public function get_name() {
        return 'cosmecos_blog_listing';
    }

    public function get_title() {
        return esc_html__('Blog Listing', 'cosmecos_plugin');
    }

    public function get_icon() {
        return 'eicon-post-list';
    }

    public function get_categories() {
        return ['cosmecos_widgets'];
    }

    public function get_script_depends() {
        return ['elementor_widgets'];
    }

    protected function _register_controls() {

        // ----------------------------- //
        // ---------- Content ---------- //
        // ----------------------------- //
        $this->start_controls_section(
            'section_content',
            [
                'label' => esc_html__('Blog Listing', 'cosmecos_plugin')
            ]
        );

        $this->add_control(
            'listing_type',
            [
                'label'     => esc_html__('Type', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'classic',
                'options'   => [
                    'classic'   => esc_html__('Classic', 'cosmecos_plugin'),
                    'grid'      => esc_html__('Grid', 'cosmecos_plugin')
                ]
            ]
        );

        $this->add_control(
            'columns_number',
            [
                'label'     => esc_html__('Columns Number', 'cosmecos_plugin'),
                'type'      => Controls_Manager::NUMBER,
                'default'   => 3,
                'min'       => 1,
                'max'       => 6,
                'condition' => [
                    'listing_type'  => 'grid'
                ]
            ]
        );

        $this->add_control(
            'posts_per_page',
            [
                'label'     => esc_html__('Items Per Page', 'cosmecos_plugin'),
                'type'      => Controls_Manager::NUMBER,
                'default'   => 3,
                'min'       => 1
            ]
        );

        $this->add_control(
            'filter_by',
            [
                'label'     => esc_html__('Filter by:', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'none',
                'options'   => [
                    'none'      => esc_html__('None', 'cosmecos_plugin'),
                    'cat'       => esc_html__('Category', 'cosmecos_plugin'),
                    'tag'       => esc_html__('Tag', 'cosmecos_plugin'),
                    'id'        => esc_html__('ID', 'cosmecos_plugin')
                ],
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'category',
            [
                'label'         => esc_html__('Categories', 'cosmecos_plugin'),
                'label_block'   => true,
                'type'          => Controls_Manager::SELECT2,
                'multiple'      => true,
                'description'   => esc_html__('List of categories.', 'cosmecos_plugin'),
                'options'       => cosmecos_get_all_blog_categories(),
                'condition'     => [
                    'filter_by'     => 'cat'
                ]
            ]
        );

        $this->add_control(
            'tag',
            [
                'label'         => esc_html__('Tags', 'cosmecos_plugin'),
                'label_block'   => true,
                'type'          => Controls_Manager::SELECT2,
                'multiple'      => true,
                'description'   => esc_html__('List of tags.', 'cosmecos_plugin'),
                'options'       => cosmecos_get_all_blog_tags(),
                'condition'     => [
                    'filter_by'     => 'tag'
                ]
            ]
        );

        $this->add_control(
            'ids',
            [
                'label'         => esc_html__('IDs', 'cosmecos_plugin'),
                'type'          => Controls_Manager::TEXT,
                'placeholder'   => esc_html__( 'Enter ID', 'cosmecos_plugin' ),
                'description'   => esc_html('Comma separated', 'cosmecos_plugin'),
                'default'       => '',
                'condition'     => [
                    'filter_by'     => 'id'
                ]
            ]
        );

        $this->add_control(
            'post_order_by',
            [
                'label'     => esc_html__('Order By', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'date',
                'options'   => [
                    'date'      => esc_html__('Post Date', 'cosmecos_plugin'),
                    'rand'      => esc_html__('Random', 'cosmecos_plugin'),
                    'ID'        => esc_html__('Post ID', 'cosmecos_plugin'),
                    'title'     => esc_html__('Post Title', 'cosmecos_plugin')
                ],
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'post_order',
            [
                'label'     => esc_html__('Order', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'desc',
                'options'   => [
                    'desc'      => esc_html__('Descending', 'cosmecos_plugin'),
                    'asc'       => esc_html__('Ascending', 'cosmecos_plugin')
                ]
            ]
        );

        $this->add_control(
            'show_cat',
            [
                'label'     => esc_html__('Categories', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__('Hide', 'cosmecos_plugin'),
                'label_on'  => esc_html__('Show', 'cosmecos_plugin'),
                'default'   => 'yes',
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'show_media',
            [
                'label'     => esc_html__('Media', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__('Hide', 'cosmecos_plugin'),
                'label_on'  => esc_html__('Show', 'cosmecos_plugin'),
                'default'   => 'yes'
            ]
        );

        $this->add_control(
            'show_author',
            [
                'label'     => esc_html__('Author', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__('Hide', 'cosmecos_plugin'),
                'label_on'  => esc_html__('Show', 'cosmecos_plugin'),
                'default'   => 'yes'
            ]
        );

        $this->add_control(
            'show_date',
            [
                'label'     => esc_html__('Date', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__('Hide', 'cosmecos_plugin'),
                'label_on'  => esc_html__('Show', 'cosmecos_plugin'),
                'default'   => 'yes'
            ]
        );

        $this->add_control(
            'show_tags',
            [
                'label'     => esc_html__('Tags', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__('Hide', 'cosmecos_plugin'),
                'label_on'  => esc_html__('Show', 'cosmecos_plugin'),
                'default'   => 'no'
            ]
        );

        $this->add_control(
            'show_title',
            [
                'label'     => esc_html__('Title', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__('Hide', 'cosmecos_plugin'),
                'label_on'  => esc_html__('Show', 'cosmecos_plugin'),
                'default'   => 'yes'
            ]
        );

        $this->add_control(
            'show_excerpt',
            [
                'label'     => esc_html__('Excerpt', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__('Hide', 'cosmecos_plugin'),
                'label_on'  => esc_html__('Show', 'cosmecos_plugin'),
                'default'   => 'yes'
            ]
        );

        $this->add_control(
            'show_read_more',
            [
                'label'     => esc_html__("'Read More' Button", 'cosmecos_plugin'),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__('Hide', 'cosmecos_plugin'),
                'label_on'  => esc_html__('Show', 'cosmecos_plugin'),
                'default'   => 'yes'
            ]
        );

        $this->add_control(
            'pagination',
            [
                'label'     => esc_html__('Pagination', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__('Hide', 'cosmecos_plugin'),
                'label_on'  => esc_html__('Show', 'cosmecos_plugin'),
                'default'   => 'yes',
                'separator' => 'before'
            ]
        );

        $this->end_controls_section();


        // -------------------------------------- //
        // ---------- General Settings ---------- //
        // -------------------------------------- //
        $this->start_controls_section(
            'general_settings_section',
            [
                'label' => esc_html__('General Settings', 'cosmecos_plugin'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->start_controls_tabs('general_border_tabs');
            // ------ Normal Tab ------ //
            $this->start_controls_tab(
                'tab_general_border_normal',
                [
                    'label' => esc_html__('Normal', 'cosmecos_plugin')
                ]
            );
                $this->add_control(
                    'item_bd_color_normal',
                    [
                        'label'     => esc_html__('Border Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .blog-item' => 'border-color: {{VALUE}};'
                        ]
                    ]
                );
            $this->end_controls_tab();

            // ------ Active Tab ------ //
            $this->start_controls_tab(
                'tab_general_border_active',
                [
                    'label' => esc_html__('Active', 'cosmecos_plugin')
                ]
            );
                $this->add_control(
                    'item_bd_color_active',
                    [
                        'label'     => esc_html__('Border Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .blog-item:hover, {{WRAPPER}} .sticky > .blog-item, {{WRAPPER}} .status-sticky > .blog-item' => 'border-color: {{VALUE}};'
                        ]
                    ]
                );
            $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->end_controls_section();


        // -------------------------------------- //
        // ---------- Content Settings ---------- //
        // -------------------------------------- //
        $this->start_controls_section(
            'content_settings_section',
            [
                'label'         => esc_html__('Content Settings', 'cosmecos_plugin'),
                'tab'           => Controls_Manager::TAB_STYLE,
                'conditions'    => [
                    'relation'      => 'or',
                    'terms'         => [
                        [
                            'name'      => 'show_author',
                            'operator'  => '===',
                            'value'     => 'yes',
                        ],
                        [
                            'name'      => 'show_date',
                            'operator'  => '===',
                            'value'     => 'yes',
                        ],
                        [
                            'name'      => 'show_tags',
                            'operator'  => '===',
                            'value'     => 'yes',
                        ],
                        [
                            'name'      => 'show_title',
                            'operator'  => '===',
                            'value'     => 'yes',
                        ],
                        [
                            'name'      => 'show_excerpt',
                            'operator'  => '===',
                            'value'     => 'yes',
                        ],
                        [
                            'name'      => 'show_read_more',
                            'operator'  => '===',
                            'value'     => 'yes',
                        ]
                    ]
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'title_typography',
                'label'     => esc_html__('Title Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .blog-item .post-title',
                'condition' => [
                    'show_title'    => 'yes'
                ]
            ]
        );

        $this->start_controls_tabs('content_title_tabs');
            // ------ Normal Tab ------ //
            $this->start_controls_tab(
                'tab_content_title_normal',
                [
                    'label'     => esc_html__('Normal', 'cosmecos_plugin'),
                    'condition' => [
                        'show_title'    => 'yes'
                    ]
                ]
            );
                $this->add_control(
                    'title_color_normal',
                    [
                        'label'     => esc_html__('Title Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .blog-item .post-title, {{WRAPPER}} .blog-item .post-title a' => 'color: {{VALUE}};'
                        ],
                        'separator' => 'after',
                        'condition' => [
                            'show_title'    => 'yes'
                        ]
                    ]
                );
            $this->end_controls_tab();

            // ------ Hover Tab ------ //
            $this->start_controls_tab(
                'tab_content_title_hover',
                [
                    'label'     => esc_html__('Hover', 'cosmecos_plugin'),
                    'condition' => [
                        'show_title'    => 'yes'
                    ]
                ]
            );
                $this->add_control(
                    'title_color_hover',
                    [
                        'label'     => esc_html__('Title Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .blog-item .post-title a:hover' => 'color: {{VALUE}};'
                        ],
                        'separator' => 'after',
                        'condition' => [
                            'show_title'    => 'yes'
                        ]
                    ]
                );
            $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'excerpt_typography',
                'label'     => esc_html__('Excerpt Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .post-content',
                'condition' => [
                    'show_excerpt' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'excerpt_color',
            [
                'label'     => esc_html__('Excerpt Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .post-content' => 'color: {{VALUE}};'
                ],
                'condition' => [
                    'show_excerpt' => 'yes'
                ],
            ]
        );

        $this->add_control(
            'excerpt_length',
            [
                'label'     => esc_html__('Excerpt Length, in simbols', 'cosmecos_plugin'),
                'type'      => Controls_Manager::NUMBER,
                'min'       => 0,
                'default'   => 190,
                'condition' => [
                    'show_excerpt' => 'yes'
                ],
                'separator' => 'after'
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'meta_typography',
                'label'     => esc_html__('Meta Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .post-meta-header .post-meta-item',
                'conditions' => [
                    'relation'  => 'or',
                    'terms'     => [
                        [
                            'name'      => 'show_author',
                            'operator'  => '===',
                            'value'     => 'yes',
                        ],
                        [
                            'name'      => 'show_date',
                            'operator'  => '===',
                            'value'     => 'yes',
                        ]
                    ]
                ]
            ]
        );

        $this->add_control(
            'meta_separator_color',
            [
                'label'     => esc_html__('Meta Separator Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .post-meta-header .post-meta-item:not(:first-child):before' => 'background-color: {{VALUE}};'
                ],
                'conditions' => [
                    'relation'  => 'or',
                    'terms'     => [
                        [
                            'name'      => 'show_author',
                            'operator'  => '===',
                            'value'     => 'yes',
                        ],
                        [
                            'name'      => 'show_date',
                            'operator'  => '===',
                            'value'     => 'yes',
                        ]
                    ]
                ]
            ]
        );

        $this->start_controls_tabs('content_meta_tabs');
            // ------ Normal Tab ------ //
            $this->start_controls_tab(
                'tab_content_meta_normal',
                [
                    'label'         => esc_html__('Normal', 'cosmecos_plugin'),
                    'conditions'    => [
                        'relation'  => 'or',
                        'terms'     => [
                            [
                                'name'      => 'show_author',
                                'operator'  => '===',
                                'value'     => 'yes',
                            ],
                            [
                                'name'      => 'show_date',
                                'operator'  => '===',
                                'value'     => 'yes',
                            ]
                        ]
                    ]
                ]
            );
                $this->add_control(
                    'meta_color_normal',
                    [
                        'label'     => esc_html__('Meta Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .post-meta-header .post-meta-item, {{WRAPPER}} .post-meta-header .post-meta-item a' => 'color: {{VALUE}};'
                        ],
                        'separator' => 'after',
                        'conditions'=> [
                            'relation'  => 'or',
                            'terms'     => [
                                [
                                    'name'      => 'show_author',
                                    'operator'  => '===',
                                    'value'     => 'yes',
                                ],
                                [
                                    'name'      => 'show_date',
                                    'operator'  => '===',
                                    'value'     => 'yes',
                                ]
                            ]
                        ]
                    ]
                );
            $this->end_controls_tab();

            // ------ Hover Tab ------ //
            $this->start_controls_tab(
                'tab_content_meta_hover',
                [
                    'label'         => esc_html__('Hover', 'cosmecos_plugin'),
                    'conditions'    => [
                        'relation'  => 'or',
                        'terms'     => [
                            [
                                'name'      => 'show_author',
                                'operator'  => '===',
                                'value'     => 'yes',
                            ],
                            [
                                'name'      => 'show_date',
                                'operator'  => '===',
                                'value'     => 'yes',
                            ]
                        ]
                    ]
                ]
            );
                $this->add_control(
                    'meta_color_hover',
                    [
                        'label'     => esc_html__('Meta Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .post-meta-header .post-meta-item a:hover' => 'color: {{VALUE}};'
                        ],
                        'separator' => 'after',
                        'conditions'=> [
                            'relation'  => 'or',
                            'terms'     => [
                                [
                                    'name'      => 'show_author',
                                    'operator'  => '===',
                                    'value'     => 'yes',
                                ],
                                [
                                    'name'      => 'show_date',
                                    'operator'  => '===',
                                    'value'     => 'yes',
                                ]
                            ]
                        ]
                    ]
                );
            $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'more_typography',
                'label'     => esc_html__('More Button Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .post-more-button a',
                'condition' => [
                    'show_read_more' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'more_color',
            [
                'label'     => esc_html__('More Button Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .post-more-button a' => 'color: {{VALUE}};'
                ],
                'condition' => [
                    'show_read_more' => 'yes'
                ],
                'separator' => 'after'
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'tags_typography',
                'label'     => esc_html__('Tags Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .post-meta-item-tags',
                'condition' => [
                    'show_tags' => 'yes'
                ]
            ]
        );

        $this->start_controls_tabs('content_tags_tabs');
            // ------ Normal Tab ------ //
            $this->start_controls_tab(
                'tab_content_tags_normal',
                [
                    'label'     => esc_html__('Normal', 'cosmecos_plugin'),
                    'condition' => [
                        'show_tags' => 'yes'
                    ]
                ]
            );
                $this->add_control(
                    'tags_color_normal',
                    [
                        'label'     => esc_html__('Tags Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'condition' => [
                            'show_tags' => 'yes'
                        ],
                        'selectors' => [
                            '{{WRAPPER}} .post-meta-item-tags, {{WRAPPER}} .post-meta-item-tags a' => 'color: {{VALUE}};'
                        ]
                    ]
                );
            $this->end_controls_tab();

            // ------ Hover Tab ------ //
            $this->start_controls_tab(
                'tab_content_tags_hover',
                [
                    'label'     => esc_html__('Hover', 'cosmecos_plugin'),
                    'condition' => [
                        'show_tags' => 'yes'
                    ]
                ]
            );
                $this->add_control(
                    'tags_color_hover',
                    [
                        'label'     => esc_html__('Meta Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .post-meta-item-tags a:hover' => 'color: {{VALUE}};'
                        ],
                        'condition' => [
                            'show_tags' => 'yes'
                        ]
                    ]
                );
            $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->end_controls_section();


        // ----------------------------------------- //
        // ---------- Pagination Settings ---------- //
        // ----------------------------------------- //
        $this->start_controls_section(
            'pagination_settings_section',
            [
                'label'     => esc_html__('Pagination Settings', 'cosmecos_plugin'),
                'tab'       => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'pagination' => 'yes'
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'pagination_typography',
                'label'     => esc_html__('Pagination Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .content-pagination .page-numbers, {{WRAPPER}} .content-pagination .post-page-numbers',
                'separator' => 'before'
            ]
        );

        $this->start_controls_tabs('pagination_tags_tabs');
            // ------ Normal Tab ------ //
            $this->start_controls_tab(
                'tab_pagination_normal',
                [
                    'label'     => esc_html__('Normal', 'cosmecos_plugin'),
                    'condition' => [
                        'pagination' => 'yes'
                    ]
                ]
            );

                $this->add_control(
                    'pagination_color',
                    [
                        'label'     => esc_html__('Pagination Text Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .content-pagination .page-numbers:not(.current):not(:hover), {{WRAPPER}} .content-pagination .post-page-numbers:not(.current):not(:hover)' => 'color: {{VALUE}};'
                        ],
                    ]
                );

                $this->add_control(
                    'pagination_border_color',
                    [
                        'label'     => esc_html__('Pagination Border Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .content-pagination .page-numbers:not(.current):not(:hover), {{WRAPPER}} .content-pagination .post-page-numbers:not(.current):not(:hover)' => 'border-color: {{VALUE}};'
                        ],
                    ]
                );

                $this->add_control(
                    'pagination_background_color',
                    [
                        'label'     => esc_html__('Pagination Background Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .content-pagination .page-numbers:not(.current):not(:hover):before, {{WRAPPER}} .content-pagination .post-page-numbers:not(.current):not(:hover):before' => 'background-color: {{VALUE}};'
                        ],
                    ]
                );

            $this->end_controls_tab();

            // ------ Hover Tab ------ //
            $this->start_controls_tab(
                'tab_pagination_active',
                [
                    'label'     => esc_html__('Active', 'cosmecos_plugin'),
                    'condition' => [
                        'pagination' => 'yes'
                    ]
                ]
            );

                $this->add_control(
                    'pagination_color_active',
                    [
                        'label'     => esc_html__('Pagination Text Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .content-pagination .page-numbers.current, {{WRAPPER}} .content-pagination .post-page-numbers.current, {{WRAPPER}} .content-pagination .page-numbers:hover, {{WRAPPER}} .content-pagination .post-page-numbers:hover' => 'color: {{VALUE}};'
                        ],
                    ]
                );

                $this->add_control(
                    'pagination_border_color_active',
                    [
                        'label'     => esc_html__('Pagination Border Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .content-pagination .page-numbers.current, {{WRAPPER}} .content-pagination .post-page-numbers.current, {{WRAPPER}} .content-pagination .page-numbers:hover, {{WRAPPER}} .content-pagination .post-page-numbers:hover' => 'border-color: {{VALUE}};'
                        ],
                    ]
                );

                $this->add_control(
                    'pagination_background_color_active',
                    [
                        'label'     => esc_html__('Pagination Background Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .content-pagination .page-numbers.current:before, {{WRAPPER}} .content-pagination .post-page-numbers.current:before, {{WRAPPER}} .content-pagination .page-numbers:hover:before, {{WRAPPER}} .content-pagination .post-page-numbers:hover:before' => 'background-color: {{VALUE}};'
                        ],
                    ]
                );

            $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->end_controls_section();


        // ----------------------------------------- //
        // ---------- Categories Settings ---------- //
        // ----------------------------------------- //
        $this->start_controls_section(
            'categories_settings_section',
            [
                'label'     => esc_html__('Categories Settings', 'cosmecos_plugin'),
                'tab'       => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'show_cat'  => 'yes'
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'cat_typography',
                'label'     => esc_html__('Categories Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .post-categories .post-category-item',
                'separator' => 'before'
            ]
        );

        $this->start_controls_tabs('content_cat_tabs');
            // ------ Normal Tab ------ //
            $this->start_controls_tab(
                'tab_content_cat_normal',
                [
                    'label'     => esc_html__('Normal', 'cosmecos_plugin')
                ]
            );
                $this->add_control(
                    'cat_color_normal',
                    [
                        'label'     => esc_html__('Categories Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .post-categories .post-category-item, {{WRAPPER}} .sticky .blog-item:after, {{WRAPPER}} .status-sticky .blog-item:after' => 'color: {{VALUE}};'
                        ]
                    ]
                );
                $this->add_control(
                    'cat_bg_normal',
                    [
                        'label'     => esc_html__('Categories Background Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .post-categories .post-category-item, {{WRAPPER}} .sticky .blog-item:after, {{WRAPPER}} .status-sticky .blog-item:after' => 'background-color: {{VALUE}};'
                        ]
                    ]
                );
            $this->end_controls_tab();

            // ------ Hover Tab ------ //
            $this->start_controls_tab(
                'tab_content_cat_hover',
                [
                    'label'     => esc_html__('Hover', 'cosmecos_plugin')
                ]
            );
                $this->add_control(
                    'cat_color_hover',
                    [
                        'label'     => esc_html__('Categories Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .post-categories .post-category-item:hover' => 'color: {{VALUE}};'
                        ]
                    ]
                );
                $this->add_control(
                    'cat_bg_hover',
                    [
                        'label'     => esc_html__('Categories Background Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .post-categories .post-category-item:hover' => 'background-color: {{VALUE}};'
                        ]
                    ]
                );
            $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings();

        $listing_type = $settings['listing_type'];
        $columns_number = ($listing_type == 'grid' && !empty($settings['columns_number']) ) ? (int)$settings['columns_number'] : 1;
        $posts_per_page = (int)$settings['posts_per_page'];
        $post_order_by = $settings['post_order_by'];
        $post_order = $settings['post_order'];
        $pagination = $settings['pagination'];
        $filter_by = $settings['filter_by'];
        $category_filter = !empty($settings['category']) && $filter_by == 'cat' ? implode(',', $settings['category']) : '';
        $tag_filter = !empty($settings['tag']) && $filter_by == 'tag' ? implode(',', $settings['tag']) : '';
        $id_filter = !empty($settings['ids']) && $filter_by == 'id' ? explode(',', str_replace(' ', '', $settings['ids'])) : '';

        $ignore_sticky_posts = !empty($settings['ids']) && $filter_by == 'id' ? true : false;

        $wrapper_class = 'archive-listing-wrapper' . ($listing_type == 'grid' && !empty($columns_number) ? ' grid-listing columns-' . esc_attr($columns_number) : '');
        $item_class = 'post' . ( $listing_type == 'grid' ? ' grid-item grid-blog-item-wrapper' : ' standard-blog-item-wrapper' );

        $excerpt_length = $settings['excerpt_length'];

        $show_cat = $settings['show_cat'];
        $show_media = $settings['show_media'];
        $show_author = $settings['show_author'];
        $show_date = $settings['show_date'];
        $show_title = $settings['show_title'];
        $show_tags = $settings['show_tags'];
        $show_excerpt = $settings['show_excerpt'];
        $show_read_more = $settings['show_read_more'];

        // ------------------------------------ //
        // ---------- Widget Content ---------- //
        // ------------------------------------ //
        ?>

        <div class="archive-listing">
            <div class="<?php echo esc_attr($wrapper_class); ?>">
                <?php
                $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;

                $args = array(
                    'post_type'             => 'post',
                    'listing_type'          => $listing_type,
                    'columns_number'        => $columns_number,
                    'posts_per_page'        => $posts_per_page,
                    'orderby'               => $post_order_by,
                    'order'                 => $post_order,
                    'paged'                 => esc_attr($paged),
                    'category_name'         => $category_filter,
                    'tag'                   => $tag_filter,
                    'post__in'              => $id_filter,
                    'ignore_sticky_posts'   => $ignore_sticky_posts
                );

                query_posts($args);

                while (have_posts()) {
                    the_post();
                    $post_format = get_post_format();
                    $cosmecos_excerpt = substr(get_the_excerpt(), 0, $excerpt_length);
                    ?>
                        <div <?php post_class(esc_attr($item_class)); ?>>
                            <div class="blog-item">
                                <?php
                                if (
                                    ( !empty(cosmecos_post_media_output()) && $show_media == 'yes' ) ||
                                    ( !empty(cosmecos_post_categories_output()) && $post_format != 'quote' && $show_cat == 'yes' )
                                ) {
                                    echo '<div class="post-media-wrapper">';
                                        if ( !empty(cosmecos_post_media_output()) && $show_media == 'yes' ) {
                                            echo cosmecos_post_media_output(true, $columns_number);
                                        }
                                        echo '<div class="post-labels">';
                                        if ( !empty(cosmecos_post_categories_output()) && $post_format != 'quote' && $show_cat == 'yes' ) {
                                            echo cosmecos_post_categories_output(true);
                                        }
                                        echo '</div>';
                                    echo '</div>';
                                }

                                if ( !($post_format == 'quote' && cosmecos_post_options() && !empty(cosmecos_get_post_option('post_media_quote_text'))) ) {
                                    if (
                                        ( !empty(cosmecos_post_date_output()) && $show_date == 'yes' ) ||
                                        ( !empty(cosmecos_post_author_output()) && $show_author == 'yes' )
                                    ) {
                                        echo '<div class="post-meta-header">';
                                        if ( !empty(cosmecos_post_date_output()) && $show_date == 'yes' ) {
                                            echo cosmecos_post_date_output(true);
                                        }
                                        if ( !empty(cosmecos_post_author_output()) && $show_author == 'yes' ) {
                                            echo cosmecos_post_author_output(true);
                                        }
                                        echo '</div>';
                                    }

                                    if ( !empty(get_the_title()) && $show_title == 'yes' ) {
                                        $title_tag = ( $listing_type == 'grid' ? 'h5' : 'h3' );
                                        echo '<' . esc_html($title_tag) . ' class="post-title"><a href="' . esc_url(get_the_permalink()) . '">' . get_the_title() . '</a></' . esc_html($title_tag) . '>';
                                    }

                                    if ( $show_excerpt == 'yes' && !empty($cosmecos_excerpt) ) {
                                        echo '<div class="post-content">' . esc_html($cosmecos_excerpt) . '</div>';
                                    }

                                    if ( !empty(cosmecos_post_tags_output()) && $show_tags == 'yes' ) {
                                        echo cosmecos_post_tags_output(', ');
                                    }

                                    if ($show_read_more == 'yes') {
                                        echo '<div class="post-more-button">';
                                            echo '<a href="' . esc_url(get_the_permalink()) . '">' . esc_html__('Read More', 'cosmecos') . '</a>';
                                        echo '</div>';
                                    }
                                }
                                ?>
                            </div>
                        </div>
                    <?php
                    }
                ?>

            </div>

            <?php
                if ($pagination == 'yes') {
            ?>
                <div class="content-pagination">
                <?php
                    echo get_the_posts_pagination(array(
                        'prev_text' => '<div class="button-icon"></div><div class="button-text">' . esc_html__('Prev', 'cosmecos') . '</div>',
                        'next_text' => '<div class="button-icon"></div><div class="button-text">' . esc_html__('Next', 'cosmecos') . '</div>'
                    ));
                ?>
                </div>
            <?php
                }
            ?>
        </div>
        <?php
        wp_reset_query();
    }

    protected function content_template() {}

    public function render_plain_content() {}
}