<?php
/*
 * Created by Artureanec
*/

namespace Cosmecos\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Cosmecos_Brands_List_Widget extends Widget_Base {

    public function get_name() {
        return 'cosmecos_brands_list';
    }

    public function get_title() {
        return esc_html__('Brands A-Z List', 'cosmecos_plugin');
    }

    public function get_icon() {
        return 'eicon-animated-headline';
    }

    public function get_categories() {
        return ['cosmecos_widgets'];
    }

    protected function _register_controls() {

        // ----------------------------- //
        // ---------- Content ---------- //
        // ----------------------------- //
        $this->start_controls_section(
            'section_styles',
            [
                'label' => esc_html__('Brands', 'cosmecos_plugin'),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'title_typography',
                'label'     => esc_html__('Heading Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .pwb-az-listing-title'
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label'     => esc_html__('Heading Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pwb-az-listing-title' => 'color: {{VALUE}};'
                ]
            ]
        );

        $this->add_control(
            'title_decoration_color',
            [
                'label'     => esc_html__('Heading Decoration Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pwb-az-listing-title:before' => 'background-color: {{VALUE}};'
                ]
            ]
        );

        $this->add_control(
            'title_separator_color',
            [
                'label'     => esc_html__('Heading Separator Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pwb-az-listing-title' => 'border-color: {{VALUE}};'
                ]
            ]
        );

        $this->add_responsive_control(
            'title_margin',
            [
                'label'     => esc_html__('Space After Title', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px'        => [
                        'min'       => 0,
                        'max'       => 300
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .pwb-az-listing-title' => 'margin-bottom: {{SIZE}}{{UNIT}};'
                ],
                'separator' => 'after'
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'brand_link_typography',
                'label'     => esc_html__('Brand Link Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .pwb-az-listing-col > a'
            ]
        );

        $this->start_controls_tabs('links_settings_tabs');

            // ------------------------ //
            // ------ Normal Tab ------ //
            // ------------------------ //
            $this->start_controls_tab(
                'tab_link_normal',
                [
                    'label' => esc_html__('Normal', 'cosmecos_plugin')
                ]
            );

                $this->add_control(
                    'brand_link_color',
                    [
                        'label'     => esc_html__('Brand Link Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .pwb-az-listing-col > a' => 'color: {{VALUE}};'
                        ]
                    ]
                );

            $this->end_controls_tab();

            // ----------------------- //
            // ------ Hover Tab ------ //
            // ----------------------- //
            $this->start_controls_tab(
                'tab_link_hover',
                [
                    'label' => esc_html__('Hover', 'cosmecos_plugin')
                ]
            );

                $this->add_control(
                    'brand_link_hover',
                    [
                        'label'     => esc_html__('Brand Link Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .pwb-az-listing-col > a:hover' => 'color: {{VALUE}};'
                        ]
                    ]
                );

            $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_responsive_control(
            'section_margin',
            [
                'label'     => esc_html__('Space Between Sections', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px'        => [
                        'min'       => 0,
                        'max'       => 300
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .pwb-az-listing-row:not(:last-child)' => 'margin-top: {{SIZE}}{{UNIT}};'
                ],
                'separator' => 'before'
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings();

        // ------------------------------------ //
        // ---------- Widget Content ---------- //
        // ------------------------------------ //


        echo '<div class="brand-list-wrapper">';
            $shortcode = '[pwb-az-listing]';
            echo do_shortcode( $shortcode );
        echo '</div>';
    }

    protected function content_template() {}

    public function render_plain_content() {}
}
