<?php

/*
 * Created by Artureanec
*/

namespace Cosmecos\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Cosmecos_Heading_Widget extends Widget_Base {

    public function get_name() {
        return 'cosmecos_heading';
    }

    public function get_title() {
        return esc_html__('Heading', 'cosmecos_plugin');
    }

    public function get_icon() {
        return 'eicon-heading';
    }

    public function get_categories() {
        return ['cosmecos_widgets'];
    }

    protected function _register_controls() {

        // ----------------------------- //
        // ---------- Content ---------- //
        // ----------------------------- //
        $this->start_controls_section(
            'section_heading',
            [
                'label' => esc_html__('Heading', 'cosmecos_plugin')
            ]
        );

        $this->add_control(
            'title_type',
            [
                'label'     => esc_html__('Heading Type', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'decoration'    => esc_html__( 'With decoration', 'cosmecos_plugin' ),
                    'subtitle'      => esc_html__( 'With subheading', 'cosmecos_plugin' )
                ],
                'default'   => 'decoration'
            ]
        );

        $this->add_control(
            'heading',
            [
                'label'         => esc_html__('Heading', 'cosmecos_plugin'),
                'type'          => Controls_Manager::WYSIWYG,
                'rows'          => '10',
                'default'       => esc_html__( 'This is heading element', 'cosmecos_plugin' ),
                'placeholder'   => esc_html__( 'Enter Your Heading', 'cosmecos_plugin' )
            ]
        );

        $this->add_control(
            'subtitle',
            [
                'label'         => esc_html__('Subheading', 'cosmecos_plugin'),
                'type'          => Controls_Manager::WYSIWYG,
                'rows'          => '10',
                'default'       => esc_html__( 'This is subheading element', 'cosmecos_plugin' ),
                'placeholder'   => esc_html__( 'Enter Your Subheading', 'cosmecos_plugin'),
                'condition'     => [
                    'title_type'    => 'subtitle'
                ]
            ]
        );

        $this->add_control(
            'title_tag',
            [
                'label'     => esc_html__('HTML Tag', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'h1'        => esc_html__( 'H1', 'cosmecos_plugin' ),
                    'h2'        => esc_html__( 'H2', 'cosmecos_plugin' ),
                    'h3'        => esc_html__( 'H3', 'cosmecos_plugin' ),
                    'h4'        => esc_html__( 'H4', 'cosmecos_plugin' ),
                    'h5'        => esc_html__( 'H5', 'cosmecos_plugin' ),
                    'h6'        => esc_html__( 'H6', 'cosmecos_plugin' ),
                    'div'       => esc_html__( 'div', 'cosmecos_plugin' ),
                    'span'      => esc_html__( 'span', 'cosmecos_plugin' ),
                    'p'         => esc_html__( 'p', 'cosmecos_plugin' )
                ],
                'default'   => 'h3'
            ]
        );

        $this->add_responsive_control(
            'title_align',
            [
                'label'     => esc_html__('Heading Alignment', 'cosmecos_plugin'),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    'left'=> [
                        'title'     => esc_html__('Left', 'cosmecos_plugin'),
                        'icon'      => 'fa fa-align-left',
                    ],
                    'center'    => [
                        'title'     => esc_html__('Center', 'cosmecos_plugin'),
                        'icon'      => 'fa fa-align-center',
                    ],
                    'right'  => [
                        'title'     => esc_html__('Right', 'cosmecos_plugin'),
                        'icon'      => 'fa fa-align-right',
                    ]
                ],
                'default'   => 'left',
                'selectors' => [
                    '{{WRAPPER}} .cosmecos-heading' => 'text-align: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        // -------------------------------------- //
        // ---------- Heading Settings ---------- //
        // -------------------------------------- //
        $this->start_controls_section(
            'section_heading_settings',
            [
                'label' => esc_html__('Heading Settings', 'cosmecos_plugin'),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'title_typography',
                'label'     => esc_html__('Heading Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .cosmecos-heading .cosmecos-heading-content'
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label'     => esc_html__('Heading Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cosmecos-heading .cosmecos-heading-content' => 'color: {{VALUE}};'
                ],
                'separator' => 'after'
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'subtitle_typography',
                'label'     => esc_html__('Subheading Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .cosmecos-subheading',
                'condition' => [
                    'title_type'    => 'subtitle'
                ]
            ]
        );

        $this->add_control(
            'subtitle_color',
            [
                'label'     => esc_html__('Subheading Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cosmecos-subheading' => 'color: {{VALUE}};'
                ],
                'condition' => [
                    'title_type'    => 'subtitle'
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'accent_text_typography',
                'label'     => esc_html__('Accent Text Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .cosmecos-heading .cosmecos-heading-content span',
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'accent_text_color',
            [
                'label'     => esc_html__('Accent Text Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cosmecos-heading .cosmecos-heading-content span' => 'color: {{VALUE}} !important;'
                ],
                'separator' => 'after'
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name'      => 'title_shadow',
                'label'     => esc_html__('Heading Text Shadow', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .cosmecos-heading'
            ]
        );

        $this->add_control(
            'title_decoration_color',
            [
                'label'     => esc_html__('Heading Decoration Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cosmecos-heading .cosmecos-title-decoration:before' => 'background-color: {{VALUE}};'
                ],
                'separator' => 'before',
                'condition' => [
                    'title_type'    => 'decoration'
                ]
            ]
        );

        $this->add_responsive_control(
            'title_margin',
            [
                'label'     => esc_html__('Space After Title', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px'        => [
                        'min'       => 0,
                        'max'       => 300
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .cosmecos-heading' => 'margin-bottom: {{SIZE}}{{UNIT}};'
                ],
                'separator' => 'before'
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {
        $settings   = $this->get_settings();
        $title_tag  = $settings['title_tag'];
        $heading    = $settings['heading'];
        $title_type = $settings['title_type'];
        $subtitle   = $settings['subtitle'];

        // ------------------------------------ //
        // ---------- Widget Content ---------- //
        // ------------------------------------ //
        if ( !empty($heading) ) {
            echo '<div class="cosmecos-heading-widget">';
                echo '<' . esc_html($title_tag) . ' class="cosmecos-heading">';
                    if ( $title_type == 'subtitle' && !empty($subtitle) ) {
                        echo '<span class="cosmecos-subheading">';
                            echo wp_kses($subtitle, array(
                                'br'    => array(),
                                'span'  => array(
                                    'style' => true
                                ),
                                'a'     => array(
                                    'href'  => true
                                ),
                                'img'   => array(
                                    'src'       => true,
                                    'srcset'    => true,
                                    'sizes'     => true,
                                    'class'     => true
                                )
                            ));
                            echo '</span>';
                    } else {
                        echo '<span class="cosmecos-title-decoration"></span>';
                    }
                    echo '<span class="cosmecos-heading-content">';
                        echo wp_kses($heading, array(
                            'br'    => array(),
                            'span'  => array(
                                'style' => true
                            ),
                            'a'     => array(
                                'href'  => true
                            ),
                            'img'   => array(
                                'src'       => true,
                                'srcset'    => true,
                                'sizes'     => true,
                                'class'     => true
                            )
                        ));
                    echo '</span>';
                echo '</' . esc_html($title_tag) . '>';
            echo '</div>';
        }
    }

    protected function content_template() {}

    public function render_plain_content() {}
}