<?php

/*
 * Created by Artureanec
*/

namespace Cosmecos\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( is_plugin_active('perfect-woocommerce-brands/perfect-woocommerce-brands.php') && class_exists('WC_Shortcode_Products') ) {
    class Cosmecos_WC_Shortcode_Products extends \WC_Shortcode_Products {
        protected function parse_attributes( $attributes ) {
            $attributes = $this->parse_legacy_attributes( $attributes );

            $attributes = shortcode_atts(
                array(
                    'limit'          => '-1',      // Results limit.
                    'columns'        => '',        // Number of columns.
                    'rows'           => '',        // Number of rows. If defined, limit will be ignored.
                    'orderby'        => '',        // menu_order, title, date, rand, price, popularity, rating, or id.
                    'order'          => '',        // ASC or DESC.
                    'ids'            => '',        // Comma separated IDs.
                    'skus'           => '',        // Comma separated SKUs.
                    'category'       => '',        // Comma separated category slugs or ids.
                    'cat_operator'   => 'IN',      // Operator to compare categories. Possible values are 'IN', 'NOT IN', 'AND'.
                    'pwb-brand'      => '',        // Comma separated brand slugs or ids.
                    'brand_operator' => 'IN',      // Operator to compare brands. Possible values are 'IN', 'NOT IN', 'AND'.
                    'attribute'      => '',        // Single attribute slug.
                    'terms'          => '',        // Comma separated term slugs or ids.
                    'terms_operator' => 'IN',      // Operator to compare terms. Possible values are 'IN', 'NOT IN', 'AND'.
                    'tag'            => '',        // Comma separated tag slugs.
                    'tag_operator'   => 'IN',      // Operator to compare tags. Possible values are 'IN', 'NOT IN', 'AND'.
                    'visibility'     => 'visible', // Product visibility setting. Possible values are 'visible', 'catalog', 'search', 'hidden'.
                    'class'          => '',        // HTML class.
                    'page'           => 1,         // Page for pagination.
                    'paginate'       => false,     // Should results be paginated.
                    'cache'          => true,      // Should shortcode output be cached.
                ),
                $attributes,
                $this->type
            );

            if ( ! absint( $attributes['columns'] ) ) {
                $attributes['columns'] = wc_get_default_products_per_row();
            }

            return $attributes;
        }

        protected function set_brands_query_args( &$query_args ) {
            if ( ! empty( $this->attributes['pwb-brand'] ) ) {
                $brands     = array_map( 'sanitize_title', explode( ',', $this->attributes['pwb-brand'] ) );
                $field      = 'slug';

                if ( is_numeric( $brands[0] ) ) {
                    $field      = 'term_id';
                    $brands = array_map( 'absint', $brands );
                    foreach ( $brands as $brand ) {
                        $the_brand = get_term_by( 'slug', $brand, 'product_cat' );
                        if ( false !== $the_brand ) {
                            $brands[] = $the_brand->term_id;
                        }
                    }
                }

                $query_args['tax_query'][] = array(
                    'taxonomy'         => 'pwb-brand',
                    'terms'            => $brands,
                    'field'            => $field,
                    'operator'         => $this->attributes['brand_operator'],
                    'include_children' => 'AND' === $this->attributes['brand_operator'] ? false : true,
                );
            }
        }

        protected function parse_query_args() {
            $query_args = array(
                'post_type'           => 'product',
                'post_status'         => 'publish',
                'ignore_sticky_posts' => true,
                'no_found_rows'       => false === wc_string_to_bool( $this->attributes['paginate'] ),
                'orderby'             => empty( $_GET['orderby'] ) ? $this->attributes['orderby'] : wc_clean( wp_unslash( $_GET['orderby'] ) ),
            );

            $orderby_value         = explode( '-', $query_args['orderby'] );
            $orderby               = esc_attr( $orderby_value[0] );
            $order                 = ! empty( $orderby_value[1] ) ? $orderby_value[1] : strtoupper( $this->attributes['order'] );
            $query_args['orderby'] = $orderby;
            $query_args['order']   = $order;

            if ( wc_string_to_bool( $this->attributes['paginate'] ) ) {
                $this->attributes['page'] = absint( empty( $_GET['product-page'] ) ? 1 : $_GET['product-page'] );
            }

            if ( ! empty( $this->attributes['rows'] ) ) {
                $this->attributes['limit'] = $this->attributes['columns'] * $this->attributes['rows'];
            }

            $ordering_args         = WC()->query->get_catalog_ordering_args( $query_args['orderby'], $query_args['order'] );
            $query_args['orderby'] = $ordering_args['orderby'];
            $query_args['order']   = $ordering_args['order'];
            if ( $ordering_args['meta_key'] ) {
                $query_args['meta_key'] = $ordering_args['meta_key'];
            }
            $query_args['posts_per_page'] = intval( $this->attributes['limit'] );
            if ( 1 < $this->attributes['page'] ) {
                $query_args['paged'] = absint( $this->attributes['page'] );
            }
            $query_args['meta_query'] = WC()->query->get_meta_query();
            $query_args['tax_query']  = array();

            // Visibility.
            $this->set_visibility_query_args( $query_args );

            // SKUs.
            $this->set_skus_query_args( $query_args );

            // IDs.
            $this->set_ids_query_args( $query_args );

            // Set specific types query args.
            if ( method_exists( $this, "set_{$this->type}_query_args" ) ) {
                $this->{"set_{$this->type}_query_args"}( $query_args );
            }

            // Attributes.
            $this->set_attributes_query_args( $query_args );

            // Categories.
            $this->set_categories_query_args( $query_args );

            // Brands.
            $this->set_brands_query_args( $query_args );

            // Tags.
            $this->set_tags_query_args( $query_args );

            $query_args = apply_filters( 'woocommerce_shortcode_products_query', $query_args, $this->attributes, $this->type );

            // Always query only IDs.
            $query_args['fields'] = 'ids';

            return $query_args;
        }

    }
}

class Cosmecos_Products_Widget extends Widget_Base {

    public function get_name() {
        return 'cosmecos_products';
    }

    public function get_title() {
        return esc_html__('Products', 'cosmecos_plugin');
    }

    public function get_icon() {
        return 'eicon-products';
    }

    public function is_reload_preview_required() {
        return true;
    }

    public function get_categories() {
        return ['cosmecos_widgets'];
    }

    public function get_script_depends() {
        return ['elementor_widgets'];
    }

    protected function _register_controls() {

        // ----------------------------- //
        // ---------- Content ---------- //
        // ----------------------------- //
        $this->start_controls_section(
            'section_display_product',
            [
                'label' => esc_html__('Display Product', 'cosmecos_plugin')
            ]
        );

        $this->add_control(
            'view_style',
            [
                'label'   => esc_html__('View Style', 'cosmecos_plugin'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'standard',
                'options' => [
                    'standard' => esc_html__('Standard', 'cosmecos_plugin'),
                    'compact'  => esc_html__('Compact', 'cosmecos_plugin')
                ]
            ]
        );

        $this->add_control(
            'products_type',
            [
                'label'   => esc_html__('Products Type', 'cosmecos_plugin'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'all',
                'options' => [
                    'all'           => esc_html__('All', 'cosmecos_plugin'),
                    'on_sale'       => esc_html__('On sale products', 'cosmecos_plugin'),
                    'best_selling'  => esc_html__('The best selling products', 'cosmecos_plugin'),
                    'top_rated'     => esc_html__('Top-rated products', 'cosmecos_plugin')
                ]
            ]
        );

        $this->add_control(
            'limit',
            [
                'label'         => esc_html__('Limit', 'cosmecos_plugin'),
                'description'   => esc_html__('The number of products to display', 'cosmecos_plugin'),
                'type'          => Controls_Manager::NUMBER,
                'min'           => -1,
                'max'           => 50,
                'default'       => 4
            ]
        );

        $this->add_control(
            'columns',
            [
                'label'         => esc_html__('Columns', 'cosmecos_plugin'),
                'description'   => esc_html__('The number of columns to display.', 'cosmecos_plugin'),
                'type'          => Controls_Manager::NUMBER,
                'min'           => 1,
                'max'           => 6,
                'default'       => 4
            ]
        );

        $this->add_control(
            'paginate',
            [
                'label'         => esc_html__('Show Pagination', 'cosmecos_plugin'),
                'description'   => esc_html__('Toggles pagination on. Use in conjunction with "limit"', 'cosmecos_plugin'),
                'type'          => Controls_Manager::SWITCHER,
                'default'       => 'no',
                'label_off'     => esc_html__('Hide', 'cosmecos_plugin'),
                'label_on'      => esc_html__('Show', 'cosmecos_plugin')
            ]
        );

        $this->add_control(
            'orderby',
            [
                'label'   => esc_html__('Orderby', 'cosmecos_plugin'),
                'type'    => Controls_Manager::SELECT,
                'description' => esc_html__('Sorts the products displayed by the entered option.', 'cosmecos_plugin'),
                'default' => 'date',
                'options' => [
                    'date'        => esc_html__('Date', 'cosmecos_plugin'),
                    'id'          => esc_html__('ID', 'cosmecos_plugin'),
                    'menu_order'  => esc_html__('Menu order', 'cosmecos_plugin'),
                    'popularity'  => esc_html__('Popularity', 'cosmecos_plugin'),
                    'rand'        => esc_html__('Random', 'cosmecos_plugin'),
                    'rating'      => esc_html__('Rating', 'cosmecos_plugin'),
                    'title'       => esc_html__('Title', 'cosmecos_plugin')
                ]
            ]
        );

        $this->add_control(
            'order',
            [
                'label'   => esc_html__('Order', 'cosmecos_plugin'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'ASC',
                'options' => [
                    'ASC'        => esc_html__('ASC', 'cosmecos_plugin'),
                    'DESC'       => esc_html__('DESC', 'cosmecos_plugin')
                ]
            ]
        );

        $cat_args = array(
            'orderby'    => 'name',
            'order'      => 'asc',
            'hide_empty' => false,
        );
        $product_categories = get_terms( 'product_cat', $cat_args );
        $category_arr = [];
        if( !empty($product_categories) ){
            foreach ($product_categories as $key => $category) {
                $category_arr[$category->slug] = $category->name;
            }
        }
        $this->add_control(
            'category',
            [
                'label'         => esc_html__('Categories', 'cosmecos_plugin'),
                'label_block'   => true,
                'type'          => Controls_Manager::SELECT2,
                'multiple'      => true,
                'description'   => esc_html__('List of categories.', 'cosmecos_plugin'),
                'options'       => $category_arr
            ]
        );

        if ( is_plugin_active('perfect-woocommerce-brands/perfect-woocommerce-brands.php') ) {
            $brand_args = array(
                'orderby'           => 'name',
                'order'             => 'asc',
                'hide_empty'        => false,
                'title_position'    => 'before'
            );
            $product_brands = get_terms( 'pwb-brand', $brand_args );
            $brands_arr = [];
            if (!empty($product_brands)) {
                foreach ($product_brands as $key => $brand) {
                    $brands_arr[$brand->slug] = $brand->name;
                }
            }
            $this->add_control(
                'brand',
                [
                    'label'         => esc_html__('Brands', 'cosmecos_plugin'),
                    'label_block'   => true,
                    'type'          => Controls_Manager::SELECT2,
                    'multiple'      => true,
                    'description'   => esc_html__('List of brands.', 'cosmecos_plugin'),
                    'options'       => $brands_arr
                ]
            );
        }

        $this->add_control(
            'skus',
            [
                'label'         => esc_html__('SKUs', 'cosmecos_plugin'),
                'label_block'   => true,
                'description'   => esc_html__('Comma-separated list of product SKUs.', 'cosmecos_plugin'),
                'type'          => Controls_Manager::TEXTAREA,
                'placeholder'   => esc_html__( 'Enter SKU list', 'cosmecos_plugin' )
            ]
        );

        $this->add_control(
            'tag',
            [
                'label'         => esc_html__('Tags', 'cosmecos_plugin'),
                'label_block'   => true,
                'description'   => esc_html__('Comma-separated list of tag slugs.', 'cosmecos_plugin'),
                'type'          => Controls_Manager::TEXTAREA,
                'placeholder'   => esc_html__( 'Enter tags list', 'cosmecos_plugin' )
            ]
        );

        $this->end_controls_section();

        // ----------------------------------- //
        // ---------- Item Settings ---------- //
        // ----------------------------------- //
        $this->start_controls_section(
            'section_item_settings',
            [
                'label' => esc_html__('Product Item Settings', 'cosmecos_plugin'),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );

        $this->start_controls_tabs('item_settings_tabs');

            // ------------------------ //
            // ------ Normal Tab ------ //
            // ------------------------ //
            $this->start_controls_tab(
                'tab_item_normal',
                [
                    'label' => esc_html__('Normal', 'cosmecos_plugin')
                ]
            );

                $this->add_control(
                    'border_color',
                    [
                        'label'     => esc_html__('Border Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .products-widget ul.products li.product .woocommerce-loop-product__wrapper .attachment-woocommerce_wrapper .attachment-woocommerce_link' => 'border-color: {{VALUE}};'
                        ]
                    ]
                );

            $this->end_controls_tab();

            // ----------------------- //
            // ------ Hover Tab ------ //
            // ----------------------- //
            $this->start_controls_tab(
                'tab_item_hover',
                [
                    'label' => esc_html__('Hover', 'cosmecos_plugin')
                ]
            );

                $this->add_control(
                    'border_hover',
                    [
                        'label'     => esc_html__('Border Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .products-widget ul.products li.product .woocommerce-loop-product__wrapper:hover .attachment-woocommerce_wrapper .attachment-woocommerce_link' => 'border-color: {{VALUE}};'
                        ]
                    ]
                );

            $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();


        // --------------------------------------- //
        // ---------- Wishlist Settings ---------- //
        // --------------------------------------- //
        $this->start_controls_section(
            'section_wishlist_settings',
            [
                'label' => esc_html__('Product Wishlist Settings', 'cosmecos_plugin'),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );

        $this->start_controls_tabs('wishlist_settings_tabs');

            // ------------------------ //
            // ------ Normal Tab ------ //
            // ------------------------ //
            $this->start_controls_tab(
                'tab_wishlist_normal',
                [
                    'label' => esc_html__('Normal', 'cosmecos_plugin')
                ]
            );

            $this->add_control(
                'wishlist_color',
                [
                    'label'     => esc_html__('Wishlist Icon Color', 'cosmecos_plugin'),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .woocommerce-loop-product__wrapper .yith-wcwl-add-to-wishlist .add_to_wishlist' => 'color: {{VALUE}};'
                    ]
                ]
            );

            $this->end_controls_tab();

            // ------------------------ //
            // ------ Active Tab ------ //
            // ------------------------ //
            $this->start_controls_tab(
                'tab_content_hover',
                [
                    'label' => esc_html__('Active', 'cosmecos_plugin')
                ]
            );

            $this->add_control(
                'wishlist_active_color',
                [
                    'label'     => esc_html__('Wishlist Active Icon Color', 'cosmecos_plugin'),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .woocommerce-loop-product__wrapper .yith-wcwl-add-to-wishlist .delete_item' => 'color: {{VALUE}};'
                    ]
                ]
            );

            $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();



        // -------------------------------------- //
        // ---------- Content Settings ---------- //
        // -------------------------------------- //
        $this->start_controls_section(
            'section_content_settings',
            [
                'label' => esc_html__('Product Content Settings', 'cosmecos_plugin'),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'title_typography',
                'label'     => esc_html__('Title Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .products-widget ul.products li.product .woocommerce-loop-product__wrapper .content-woocommerce-wrapper .woocommerce-loop-product-title, {{WRAPPER}} .products-widget ul.products li.product .woocommerce-loop-product__wrapper .content-woocommerce-wrapper h3'
            ]
        );

        $this->start_controls_tabs('title_settings_tabs' );

            // ------------------------ //
            // ------ Normal Tab ------ //
            // ------------------------ //
            $this->start_controls_tab(
                'tab_title_normal',
                [
                    'label' => esc_html__('Normal', 'cosmecos_plugin')
                ]
            );

            $this->add_control(
                'title_color',
                [
                    'label'     => esc_html__('Title Color', 'cosmecos_plugin'),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .products-widget ul.products li.product .woocommerce-loop-product__wrapper .content-woocommerce-wrapper .woocommerce-loop-product-title, {{WRAPPER}} .products-widget ul.products li.product .woocommerce-loop-product__wrapper .content-woocommerce-wrapper h3, {{WRAPPER}} .products-widget ul.products li.product .woocommerce-loop-product__wrapper .content-woocommerce-wrapper .woocommerce-loop-product-title a, {{WRAPPER}} .products-widget ul.products li.product .woocommerce-loop-product__wrapper .content-woocommerce-wrapper h3 a' => 'color: {{VALUE}};'
                    ],
                    'separator' => 'after'
                ]
            );

            $this->end_controls_tab();

            // ----------------------- //
            // ------ Hover Tab ------ //
            // ----------------------- //
            $this->start_controls_tab(
                'tab_title_hover',
                [
                    'label' => esc_html__('Hover', 'cosmecos_plugin')
                ]
            );

            $this->add_control(
                'title_hover',
                [
                    'label'     => esc_html__('Title Hover', 'cosmecos_plugin'),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .products-widget ul.products li.product .woocommerce-loop-product__wrapper .content-woocommerce-wrapper .woocommerce-loop-product-title a:hover, {{WRAPPER}} .products-widget ul.products li.product .woocommerce-loop-product__wrapper .content-woocommerce-wrapper h3 a:hover' => 'color: {{VALUE}};'
                    ],
                    'separator' => 'after'
                ]
            );

            $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'price_typography',
                'label'     => esc_html__('Price Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .product-info-wrapper .price',
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'current_price_color',
            [
                'label'     => esc_html__('Current Price Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product .price' => 'color: {{VALUE}};'
                ]
            ]
        );

        $this->add_control(
            'old_price_color',
            [
                'label'     => esc_html__('Old Price Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product .woocommerce-loop-product__wrapper .content-woocommerce-wrapper .price del' => 'color: {{VALUE}};'
                ]
            ]
        );

        $this->add_control(
            'rating_default_color',
            [
                'label'     => esc_html__('Rating Inactive Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .star-rating:before' => 'color: {{VALUE}};'
                ],
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'rating_active_color',
            [
                'label'     => esc_html__('Rating Active Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .star-rating span' => 'color: {{VALUE}};'
                ],
                'separator' => 'after'
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'brand_typography',
                'label'     => esc_html__('Brand Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .products-widget ul.products li.product .woocommerce-loop-product__wrapper .content-woocommerce-wrapper .pwb-brands-in-loop',
                'separator' => 'before'
            ]
        );

        $this->start_controls_tabs('brand_settings_tabs' );

            // ------------------------ //
            // ------ Normal Tab ------ //
            // ------------------------ //
            $this->start_controls_tab(
                'tab_brand_normal',
                [
                    'label' => esc_html__('Normal', 'cosmecos_plugin')
                ]
            );

                $this->add_control(
                    'brand_color',
                    [
                        'label'     => esc_html__('Brand Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .pwb-brands-in-loop, {{WRAPPER}} .pwb-brands-in-loop a' => 'color: {{VALUE}};'
                        ]
                    ]
                );

            $this->end_controls_tab();

            // ----------------------- //
            // ------ Hover Tab ------ //
            // ----------------------- //
            $this->start_controls_tab(
                'tab_brand_hover',
                [
                    'label' => esc_html__('Hover', 'cosmecos_plugin')
                ]
            );

                $this->add_control(
                    'brand_hover',
                    [
                        'label'     => esc_html__('Brand Hover', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .pwb-brands-in-loop a:hover' => 'color: {{VALUE}};'
                        ]
                    ]
                );

            $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();



        // ------------------------------------- //
        // ---------- Button Settings ---------- //
        // ------------------------------------- //
        $this->start_controls_section(
            'section_button_settings',
            [
                'label' => esc_html__('Product Button Settings', 'cosmecos_plugin'),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'button_typography',
                'label'     => esc_html__('Button Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .product-info-wrapper a.button, {{WRAPPER}} .product-info-wrapper a.added_to_cart'
            ]
        );

        $this->start_controls_tabs('button_settings_tabs');

            // ------------------------ //
            // ------ Normal Tab ------ //
            // ------------------------ //
            $this->start_controls_tab(
                'tab_button_normal',
                [
                    'label' => esc_html__('Normal', 'cosmecos_plugin')
                ]
            );

                $this->add_control(
                    'button_color',
                    [
                        'label'     => esc_html__('Button Text Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .product-info-wrapper a.button, {{WRAPPER}} .product-info-wrapper a.added_to_cart' => 'color: {{VALUE}};'
                        ]
                    ]
                );

                $this->add_control(
                    'button_bg_color',
                    [
                        'label'     => esc_html__('Button Background Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .product-info-wrapper a.button:after, {{WRAPPER}} .product-info-wrapper a.added_to_cart:after' => 'background-color: {{VALUE}};'
                        ]
                    ]
                );

                $this->add_control(
                    'button_bd_color',
                    [
                        'label'     => esc_html__('Button Border Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .product-info-wrapper a.button, {{WRAPPER}} .product-info-wrapper a.added_to_cart, {{WRAPPER}} .products-widget ul.products li.product .woocommerce-loop-product__wrapper .product-info-wrapper .price' => 'border-color: {{VALUE}};'
                        ]
                    ]
                );

            $this->end_controls_tab();

            // ----------------------- //
            // ------ Hover Tab ------ //
            // ----------------------- //
            $this->start_controls_tab(
                'tab_button_hover',
                [
                    'label' => esc_html__('Hover', 'cosmecos_plugin')
                ]
            );

                $this->add_control(
                    'button_hover_color',
                    [
                        'label'     => esc_html__('Button Text Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .product-info-wrapper a.button:hover, {{WRAPPER}} .product-info-wrapper a.added_to_cart:hover' => 'color: {{VALUE}};'
                        ]
                    ]
                );

                $this->add_control(
                    'button_hover_bg_color',
                    [
                        'label'     => esc_html__('Button Background Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .product-info-wrapper a.button:hover:after, {{WRAPPER}} .product-info-wrapper a.added_to_cart:hover:after' => 'background-color: {{VALUE}};'
                        ]
                    ]
                );

            $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->end_controls_section();
    }

    protected function render() {
        $settings       = $this->get_settings();
        $view_style     = $settings['view_style'];

        $products_type = $settings['products_type'];

        $limit      = $settings['limit'];
        $columns    = $settings['columns'];
        $paginate   = $settings['paginate'];
        $orderby    = $settings['orderby'];
        $order      = $settings['order'];
        $category   = (!empty($settings['category']) ? implode(',', $settings['category']) : '');
        $brand      = (!empty($settings['brand'] && isset($settings['brand'])) ? implode(',', $settings['brand']) : '');
        $skus       = $settings['skus'];
        $tag        = $settings['tag'];

        $classes    = (!empty($view_style) ? ' view-type-' . esc_attr($view_style) : '');

        // ------------------------------------ //
        // ---------- Widget Content ---------- //
        // ------------------------------------ //
        ?>
        <div class="products-widget<?php echo esc_attr($classes); ?>">
            <?php
                $atts = array(
                    'limit'          => $limit,
                    'columns'        => $columns,
                    'orderby'        => $orderby,
                    'order'          => $order,
                    'skus'           => $skus,
                    'category'       => $category,
                    'tag'            => $tag,
                    'visibility'     => 'visible',
                    'class'          => 'cosmecos_shop_loop',
                    'page'           => 1,
                    'paginate'       => $paginate
                );
                if ( is_plugin_active('perfect-woocommerce-brands/perfect-woocommerce-brands.php') && !empty($brand) ) {
                    $atts['pwb-brand'] = $brand;
                }

                $type = 'products';
                if ( $products_type == 'on_sale' ) {
                    $atts['on_sale'] = 'true';
                    $type = 'sale_products';
                } elseif ( $products_type == 'best_selling' ) {
                    $atts['best_selling'] = 'true';
                    $type = 'best_selling_products';
                } elseif ( $products_type == 'top_rated' ) {
                    $atts['top_rated'] = 'true';
                    $type = 'top_rated_products';
                }

                $shortcode = new Cosmecos_WC_Shortcode_Products( $atts, $type );

                echo $shortcode->get_content();
            ?>
        </div>
        <?php
    }

    protected function content_template() {}

    public function render_plain_content() {}
}
