<?php
/*
 * Created by Artureanec
*/

namespace Cosmecos\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\REPEATER;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Cosmecos_Testimonial_Carousel_Widget extends Widget_Base {

    public function get_name() {
        return 'cosmecos_testimonial_carousel';
    }

    public function get_title() {
        return esc_html__('Testimonial Carousel', 'cosmecos_plugin');
    }

    public function get_icon() {
        return 'eicon-testimonial-carousel';
    }

    public function get_categories() {
        return ['cosmecos_widgets'];
    }

    public function get_script_depends() {
        return ['elementor_widgets'];
    }

    protected function _register_controls() {

        // ----------------------------- //
        // ---------- Content ---------- //
        // ----------------------------- //
        $this->start_controls_section(
            'section_content',
            [
                'label' => esc_html__('Testimonial Carousel', 'cosmecos_plugin')
            ]
        );

        $this->add_control(
            'view_type',
            [
                'label'     => esc_html__('View Type', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'type-1',
                'options'   => [
                    'type-1'    => esc_html__('Type 1', 'cosmecos_plugin'),
                    'type-2'    => esc_html__('Type 2', 'cosmecos_plugin'),
                    'type-3'    => esc_html__('Type 3', 'cosmecos_plugin'),
                    'type-4'    => esc_html__('Type 4', 'cosmecos_plugin')
                ]
            ]
        );

        $this->add_control(
            'title',
            [
                'label'         => esc_html__('Carousel Title', 'cosmecos_plugin'),
                'type'          => Controls_Manager::TEXT,
                'placeholder'   => esc_html__('Enter Title', 'cosmecos_plugin'),
                'default'       => '',
                'condition'     => [
                    'view_type'     => ['type-2', 'type-3', 'type-4']
                ]
            ]
        );

        $this->add_control(
            'subtitle',
            [
                'label'         => esc_html__('Carousel Subtitle', 'cosmecos_plugin'),
                'type'          => Controls_Manager::TEXT,
                'placeholder'   => esc_html__('Enter Subtitle', 'cosmecos_plugin'),
                'default'       => '',
                'condition'     => [
                    'view_type'     => ['type-3', 'type-4']
                ]
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'testimonial',
            [
                'label'         => esc_html__('Testimonial Text', 'cosmecos_plugin'),
                'type'          => Controls_Manager::WYSIWYG,
                'rows'          => '10',
                'default'       => '',
                'placeholder'   => esc_html__('Enter Testimonial Text', 'cosmecos_plugin'),
                'separator'     => 'before'
            ]
        );

        $repeater->add_control(
            'photo',
            [
                'label'     => esc_html__( 'Choose Author Photo', 'cosmecos_plugin' ),
                'type'      => Controls_Manager::MEDIA,
                'dynamic'   => [
                    'active'    => true,
                ],
            ]
        );

        $repeater->add_control(
            'name',
            [
                'label'     => esc_html__('Author Name', 'cosmecos_plugin'),
                'type'      => Controls_Manager::TEXT,
                'default'   => ''
            ]
        );

        $repeater->add_control(
            'position',
            [
                'label'     => esc_html__('Author Position', 'cosmecos_plugin'),
                'type'      => Controls_Manager::TEXT,
                'default'   => ''
            ]
        );

        $repeater->add_control(
            'additional_image',
            [
                'label'         => esc_html__( 'Choose Additional Image', 'cosmecos_plugin' ),
                'type'          => Controls_Manager::MEDIA,
                'dynamic'       => [
                    'active'        => true,
                ],
                'description'   => esc_html__('For example, a signature', 'cosmecos_plugin')
            ]
        );

        $this->add_control(
            'testimonials_items',
            [
                'label'         => esc_html__('Testimonials', 'cosmecos_plugin'),
                'type'          => Controls_Manager::REPEATER,
                'fields'        => $repeater->get_controls(),
                'title_field'   => '{{{name}}}',
                'prevent_empty' => false,
                'separator'     => 'before'
            ]
        );

        $this->end_controls_section();

        // ---------------------------- //
        // ---------- Slider ---------- //
        // ---------------------------- //
        $this->start_controls_section(
            'section_slider',
            [
                'label' => esc_html__('Slider Settings', 'cosmecos_plugin')
            ]
        );

        $this->add_control(
            'speed',
            [
                'label'     => esc_html__('Animation Speed', 'cosmecos_plugin'),
                'type'      => Controls_Manager::NUMBER,
                'default'   => 500,
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'infinite',
            [
                'label'     => esc_html__('Infinite Loop', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'yes',
                'options'   => [
                    'yes'       => esc_html__('Yes', 'cosmecos_plugin'),
                    'no'        => esc_html__('No', 'cosmecos_plugin'),
                ],
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'autoplay',
            [
                'label'     => esc_html__('Autoplay', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'yes',
                'options'   => [
                    'yes'       => esc_html__('Yes', 'cosmecos_plugin'),
                    'no'        => esc_html__('No', 'cosmecos_plugin'),
                ],
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'autoplay_speed',
            [
                'label'     => esc_html__('Autoplay Speed', 'cosmecos_plugin'),
                'type'      => Controls_Manager::NUMBER,
                'default'   => 300,
                'step'      => 100,
                'condition' => [
                    'autoplay'  => 'yes'
                ]
            ]
        );

        $this->add_control(
            'autoplay_timeout',
            [
                'label'     => esc_html__('Autoplay Timeout', 'cosmecos_plugin'),
                'type'      => Controls_Manager::NUMBER,
                'default'   => 5000,
                'step'      => 100,
                'condition' => [
                    'autoplay'  => 'yes'
                ]
            ]
        );

        $this->add_control(
            'pause_on_hover',
            [
                'label'     => esc_html__('Pause on Hover', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'yes',
                'options'   => [
                    'yes'       => esc_html__('Yes', 'cosmecos_plugin'),
                    'no'        => esc_html__('No', 'cosmecos_plugin'),
                ],
                'condition' => [
                    'autoplay'  => 'yes'
                ]
            ]
        );

        $this->end_controls_section();

        // ----------------------------------------- //
        // ---------- Pagination Settings ---------- //
        // ----------------------------------------- //
        $this->start_controls_section(
            'section_pagination_settings',
            [
                'label' => esc_html__('Pagination Settings', 'cosmecos_plugin'),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );

        $this->start_controls_tabs('button_settings_tabs');

            // ------------------------ //
            // ------ Normal Tab ------ //
            // ------------------------ //
            $this->start_controls_tab(
                'pagination_normal',
                [
                    'label' => esc_html__('Normal', 'cosmecos_plugin')
                ]
            );

                $this->add_control(
                    'dot_color',
                    [
                        'label'     => esc_html__('Pagination Dot Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .owl-dots .owl-dot span:after' => 'background: {{VALUE}};'
                        ]
                    ]
                );

                $this->add_control(
                    'dot_border',
                    [
                        'label'     => esc_html__('Pagination Dot Border', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .owl-dots .owl-dot span' => 'border-color: {{VALUE}};'
                        ]
                    ]
                );

            $this->end_controls_tab();

            // ------------------------ //
            // ------ Active Tab ------ //
            // ------------------------ //
            $this->start_controls_tab(
                'pagination_active',
                [
                    'label' => esc_html__('Active', 'cosmecos_plugin')
                ]
            );

                $this->add_control(
                    'dot_active',
                    [
                        'label'     => esc_html__('Pagination Active Dot Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .owl-dots .owl-dot.active span:after' => 'background: {{VALUE}};'
                        ]
                    ]
                );

                $this->add_control(
                    'dot_border_active',
                    [
                        'label'     => esc_html__('Pagination Active Dot Border', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .owl-dots .owl-dot.active span' => 'border-color: {{VALUE}};'
                        ]
                    ]
                );

            $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        // ----------------------------------------- //
        // ---------- Navigation Settings ---------- //
        // ----------------------------------------- //
        $this->start_controls_section(
            'section_navigation_settings',
            [
                'label'     => esc_html__('Navigation Settings', 'cosmecos_plugin'),
                'tab'       => Controls_Manager::TAB_STYLE
            ]
        );

        $this->start_controls_tabs('pagination_settings_tabs');

            // ------------------------ //
            // ------ Normal Tab ------ //
            // ------------------------ //
            $this->start_controls_tab(
                'navigation_normal',
                [
                    'label' => esc_html__('Normal', 'cosmecos_plugin')
                ]
            );

            $this->add_control(
                'nav_color',
                [
                    'label'     => esc_html__('Navigation Arrow Color', 'cosmecos_plugin'),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .owl-nav .owl-prev, {{WRAPPER}} .owl-nav .owl-next' => 'color: {{VALUE}};'
                    ]
                ]
            );

            $this->add_control(
                'nav_border',
                [
                    'label'     => esc_html__('Navigation Button Border', 'cosmecos_plugin'),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .owl-nav .owl-prev, {{WRAPPER}} .owl-nav .owl-next' => 'border-color: {{VALUE}};'
                    ]
                ]
            );

            $this->add_control(
                'nav_background',
                [
                    'label'     => esc_html__('Navigation Button Background', 'cosmecos_plugin'),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .owl-nav .owl-prev:before, {{WRAPPER}} .owl-nav .owl-next:before' => 'background-color: {{VALUE}};'
                    ]
                ]
            );

            $this->end_controls_tab();

            // ----------------------- //
            // ------ Hover Tab ------ //
            // ----------------------- //
            $this->start_controls_tab(
                'navigation_hover',
                [
                    'label' => esc_html__('Hover', 'cosmecos_plugin')
                ]
            );

            $this->add_control(
                'nav_hover',
                [
                    'label'     => esc_html__('Navigation Arrow Color', 'cosmecos_plugin'),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .owl-nav .owl-prev:hover, {{WRAPPER}} .owl-nav .owl-next:hover' => 'color: {{VALUE}};'
                    ]
                ]
            );

            $this->add_control(
                'nav_border_hover',
                [
                    'label'     => esc_html__('Navigation Button Border', 'cosmecos_plugin'),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .owl-nav .owl-prev:hover, {{WRAPPER}} .owl-nav .owl-next:hover' => 'border-color: {{VALUE}};'
                    ]
                ]
            );

            $this->add_control(
                'nav_background_hover',
                [
                    'label'     => esc_html__('Navigation Button Background', 'cosmecos_plugin'),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .owl-nav .owl-prev:hover:before, {{WRAPPER}} .owl-nav .owl-next:hover:before' => 'background-color: {{VALUE}};'
                    ]
                ]
            );

            $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        // -------------------------------------- //
        // ---------- Content Settings ---------- //
        // -------------------------------------- //
        $this->start_controls_section(
            'section_content_settings',
            [
                'label' => esc_html__('Content Settings', 'cosmecos_plugin'),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_control(
            'slider_bg_color',
            [
                'label'     => esc_html__('Background Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-carousel-wrapper.view-type-4, {{WRAPPER}} .testimonial-carousel-wrapper.view-type-4 .testimonial-carousel-corner:after' => 'background-color: {{VALUE}};'
                ],
                'condition' => [
                    'view_type' => ['type-4']
                ]
            ]
        );

        $this->add_control(
            'slider_bd_color',
            [
                'label'     => esc_html__('Border Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-carousel-wrapper.view-type-4:before, {{WRAPPER}} .testimonial-carousel-wrapper.view-type-4 .testimonial-carousel-corner:before' => 'border-color: {{VALUE}};'
                ],
                'condition' => [
                    'view_type' => ['type-4']
                ],
                'separator' => 'after'
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label'     => esc_html__('Title Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-carousel-wrapper .testimonial-carousel-title' => 'color: {{VALUE}};'
                ],
                'condition' => [
                    'view_type' => ['type-2', 'type-3', 'type-4']
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'title_typography',
                'label'     => esc_html__('Title Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .testimonial-carousel-wrapper .testimonial-carousel-title',
                'condition' => [
                    'view_type' => ['type-2', 'type-3', 'type-4']
                ]
            ]
        );

        $this->add_control(
            'subtitle_color',
            [
                'label'     => esc_html__('Subtitle Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-carousel-wrapper .testimonial-carousel-subtitle' => 'color: {{VALUE}};'
                ],
                'condition' => [
                    'view_type' => ['type-3', 'type-4']
                ],
                'separator' => 'before'
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'subtitle_typography',
                'label'     => esc_html__('Subtitle Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .testimonial-carousel-wrapper .testimonial-carousel-subtitle',
                'condition' => [
                    'view_type' => ['type-3', 'type-4']
                ]
            ]
        );

        $this->add_control(
            'icon_color',
            [
                'label'     => esc_html__('Quote Icon Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .testimonial-item .testimonial:before, {{WRAPPER}} .testimonial-carousel-title:before, {{WRAPPER}} .cosmecos-testimonial-carousel-widget .testimonial-carousel-wrapper.view-type-4:after' => 'color: {{VALUE}};'
                ],
                'condition' => [
                    'view_type' => ['type-2', 'type-3', 'type-4']
                ]
            ]
        );

        $this->add_control(
            'icon_opacity',
            [
                'label'     => esc_html__('Quote Icon Opacity', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    '%'         => [
                        'min'       => 0,
                        'max'       => 1,
                        'step'      => .01
                    ]
                ],
                'default'   => [
                    'unit'      => '%',
                    'size'      => 0.2,
                ],
                'selectors' => [
                    '{{WRAPPER}} .testimonial-item .testimonial:before, {{WRAPPER}} .testimonial-carousel-title:before, {{WRAPPER}} .cosmecos-testimonial-carousel-widget .testimonial-carousel-wrapper.view-type-4:after' => 'opacity: {{SIZE}};'
                ],
                'condition' => [
                    'view_type' => ['type-2', 'type-3', 'type-4']
                ],
                'separator' => 'after'
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'text_typography',
                'label'     => esc_html__('Testimonial Text Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .testimonial-item .testimonial',
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'text_color',
            [
                'label'     => esc_html__('Testimonial Text Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'separator' => 'after',
                'selectors' => [
                    '{{WRAPPER}} .testimonial-item .testimonial' => 'color: {{VALUE}};'
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'author_typography',
                'label'     => esc_html__('Author Name Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .author-name',
            ]
        );

        $this->add_control(
            'author_color',
            [
                'label'     => esc_html__('Author Name Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'separator' => 'after',
                'selectors' => [
                    '{{WRAPPER}} .author-name' => 'color: {{VALUE}};'
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'position_typography',
                'label'     => esc_html__('Author Position Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .author-position',
            ]
        );

        $this->add_control(
            'position_color',
            [
                'label'     => esc_html__('Author Position Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .author-position' => 'color: {{VALUE}};'
                ]
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        $settings           = $this->get_settings();

        $view_type          = $settings['view_type'];
        $title              = $settings['title'];
        $subtitle           = $settings['subtitle'];
        $testimonials_items = $settings['testimonials_items'];

        $slider_options = [
            'items'                 => 1,
            'autoplayHoverPause'    => ('yes' === $settings['pause_on_hover']),
            'autoplay'              => ('yes' === $settings['autoplay']),
            'autoplaySpeed'         => absint($settings['autoplay_speed']),
            'autoplayTimeout'       => absint($settings['autoplay_timeout']),
            'loop'                  => ('yes' === $settings['infinite']),
            'speed'                 => absint($settings['speed']),
            'singleItem'            => true
        ];

        // ------------------------------------ //
        // ---------- Widget Content ---------- //
        // ------------------------------------ //
        ?>

        <div class="cosmecos-testimonial-carousel-widget">
            <div class="testimonial-carousel-wrapper view-<?php echo esc_attr($view_type); ?>">
                <?php
                    if ( ( $view_type == 'type-3' || $view_type == 'type-4' ) && !empty($subtitle) ) {
                        echo '<div class="testimonial-carousel-corner"></div>';
                        echo '<div class="testimonial-carousel-subtitle">' . esc_html($subtitle) . '</div>';
                    }
                    if ( ( $view_type == 'type-2' || $view_type == 'type-3' || $view_type == 'type-4' ) && !empty($title) ) {
                        echo '<h3 class="testimonial-carousel-title">' . esc_html($title) . '</h3>';
                    }
                ?>
                <div class="testimonials-slider-container">
                    <div class="testimonials-slider owl-carousel owl-theme slider-<?php echo esc_attr($view_type); ?>" data-slider-options="<?php echo esc_attr(wp_json_encode($slider_options)); ?>">
                        <?php

                        foreach ($testimonials_items as $item) {
                            if ( $view_type == 'type-1' || $view_type == 'type-3' ) {
                                $image_src = wp_get_attachment_image_url($item['photo']['id'], array(75, 75));
                                $image_alt_text = get_post_meta(get_post_thumbnail_id($item['photo']['id']), '_wp_attachment_image_alt', true);

                                $image = '<img src="' . esc_url($image_src) . '" alt="' . esc_attr($image_alt_text) . '" >';

                                $sign_src = wp_get_attachment_image_url($item['additional_image']['id'], array(150, 75));
                                $sign_alt_text = get_post_meta(get_post_thumbnail_id($item['additional_image']['id']), '_wp_attachment_image_alt', true);

                                $sign = '<img src="' . esc_url($sign_src) . '" alt="' . esc_attr($sign_alt_text) . '" >';

                                echo '<div class="testimonial-item">';
                                    echo ( !empty($item['testimonial']) ? '<div class="testimonial">' . cosmecos_output_code($item['testimonial']) . '</div>' : '' );
                                    echo '<div class="author-container">';
                                        if ( !empty($item['photo']['url']) && !empty($image) ) {
                                            echo '<div class="testimonial-photo">';
                                            echo wp_kses($image, array(
                                                'img' => array(
                                                    'src' => true,
                                                    'alt' => true
                                                )
                                            ));
                                            echo '</div>';
                                        }
                                        echo '<div class="author-info">';
                                            echo ( !empty($item['name']) ? '<div class="author-name">' . esc_html($item['name']) . '</div>' : '' );
                                            echo ( !empty($item['position']) ? '<div class="author-position">' . esc_html($item['position']) . '</div>' : '' );
                                        echo '</div>';
                                        if ( !empty($item['additional_image']['url']) && !empty($sign) ) {
                                            echo '<div class="testimonial-additional-image">';
                                            echo wp_kses($sign, array(
                                                'img' => array(
                                                    'src' => true,
                                                    'alt' => true
                                                )
                                            ));
                                            echo '</div>';
                                        }
                                    echo '</div>';
                                echo '</div>';
                            }
                            if ( $view_type == 'type-2' ) {
                                $image_src = wp_get_attachment_image_url($item['photo']['id'], array(85, 85));
                                $image_alt_text = get_post_meta(get_post_thumbnail_id($item['photo']['id']), '_wp_attachment_image_alt', true);

                                $image = '<img src="' . esc_url($image_src) . '" alt="' . esc_attr($image_alt_text) . '" >';

                                echo '<div class="testimonial-item">';
                                    echo ( !empty($item['testimonial']) ? '<div class="testimonial">' . cosmecos_output_code($item['testimonial']) . '</div>' : '' );
                                    echo '<div class="author-container">';
                                        if ( !empty($item['photo']['url']) && !empty($image) ) {
                                            echo '<div class="testimonial-photo">';
                                                echo wp_kses($image, array(
                                                    'img' => array(
                                                        'src' => true,
                                                        'alt' => true
                                                    )
                                                ));
                                            echo '</div>';
                                        }
                                        echo '<div class="author-info">';
                                            echo ( !empty($item['name']) ? '<div class="author-name">' . esc_html($item['name']) . '</div>' : '' );
                                            echo ( !empty($item['position']) ? '<div class="author-position">' . esc_html($item['position']) . '</div>' : '' );
                                        echo '</div>';
                                    echo '</div>';
                                echo '</div>';
                            }
                            if ( $view_type == 'type-4' ) {
                                $image_src = wp_get_attachment_image_url($item['photo']['id'], array(85, 85));
                                $image_alt_text = get_post_meta(get_post_thumbnail_id($item['photo']['id']), '_wp_attachment_image_alt', true);

                                $image = '<img src="' . esc_url($image_src) . '" alt="' . esc_attr($image_alt_text) . '" >';

                                echo '<div class="testimonial-item">';
                                    echo ( !empty($item['testimonial']) ? '<div class="testimonial">' . cosmecos_output_code($item['testimonial']) . '</div>' : '' );
                                        echo '<div class="author-container">';
                                        if ( !empty($item['photo']['url']) && !empty($image) ) {
                                            echo '<div class="testimonial-photo">';
                                            echo wp_kses($image, array(
                                                'img' => array(
                                                    'src' => true,
                                                    'alt' => true
                                                )
                                            ));
                                            echo '</div>';
                                        }
                                        echo '<div class="author-info">';
                                            echo ( !empty($item['name']) ? '<div class="author-name">' . esc_html($item['name']) . '</div>' : '' );
                                            echo ( !empty($item['position']) ? '<div class="author-position">' . esc_html($item['position']) . '</div>' : '' );
                                        echo '</div>';
                                    echo '</div>';
                                echo '</div>';
                            }
                        }
                        ?>
                    </div>
                </div>
            </div>
        </div>

        <?php
    }

    protected function content_template() {}

    public function render_plain_content() {}
}