<?php
/*
 * Created by Artureanec
*/

// Hex 2 RGB
if (!function_exists('cosmecos_hex2rgb')) {
    function cosmecos_hex2rgb($hex) {
        $hex = str_replace("#", "", $hex);

        if (strlen($hex) == 3) {
            $r = hexdec(substr($hex, 0, 1) . substr($hex, 0, 1));
            $g = hexdec(substr($hex, 1, 1) . substr($hex, 1, 1));
            $b = hexdec(substr($hex, 2, 1) . substr($hex, 2, 1));
        } else {
            $r = hexdec(substr($hex, 0, 2));
            $g = hexdec(substr($hex, 2, 2));
            $b = hexdec(substr($hex, 4, 2));
        }
        return $r . "," . $g . "," . $b;
    }
}

// Custom get_theme_mod
if (!function_exists('cosmecos_get_theme_mod')) {
    function cosmecos_get_theme_mod($name) {
        if (func_num_args() > 1) {
            die(sprintf(esc_html__('The cosmecos_get_theme_mod("%s") function takes only one argument. Define default values in core/customizer.php', 'cosmecos'), $name));
        }

        global $cosmecos_customizer_default_values;

        if (!isset($cosmecos_customizer_default_values[$name])) {
            die(sprintf(esc_html__('Error! You did not add the default value for the "%s" option! core/customizer.php', 'cosmecos'), $name));
        }
        return get_theme_mod($name, $cosmecos_customizer_default_values[$name]);
    }
}

// Get WooCommerce Endpoint Page ID
if (!function_exists('cosmecos_get_wc_endpoint_page_id')) {
    function cosmecos_get_wc_endpoint_page_id() {
        global $post;
        $page_id = get_the_ID();
        if ( class_exists('WooCommerce') &&  is_woocommerce() ) {
            if ( is_shop() || is_product_category() || is_product_taxonomy() || is_product_tag() ) {
                $page_id = wc_get_page_id('shop');
            } elseif ( is_cart() ) {
                $page_id = wc_get_page_id('cart');
            } elseif ( is_checkout() ) {
                $page_id = wc_get_page_id('checkout');
            } elseif ( is_account_page() ) {
                $page_id = wc_get_page_id('myaccount');
            } elseif ( is_product() ) {
                global $product;
                if ( is_object($product) ) {
                    $page_id = $product->get_id();
                } else {
                    $product_obj = get_page_by_path( $product, OBJECT, 'product' );
                    $page_id = $product_obj->ID;
                }
            }
            $post = get_post($page_id);
        }
    }
}

// Get Preferred Option
if (!function_exists('cosmecos_get_prefered_option')) {
    function cosmecos_get_prefered_option($name) {
        if (func_num_args() > 1) {
            die (sprintf(esc_html__('The cosmecos_get_prefered_option ("%s") function may takes only one argument.', 'cosmecos'), $name));
        }

        global $cosmecos_customizer_default_values;
        cosmecos_get_wc_endpoint_page_id();


        if (!isset($cosmecos_customizer_default_values[$name])) {
            die (sprintf(esc_html__('Error! You did not add the default value for the "%s" option! core/customizer.php.', 'cosmecos'), $name));
        }

        if (cosmecos_get_post_option($name) && cosmecos_get_post_option($name) !== 'default') {
            return cosmecos_get_post_option($name, $cosmecos_customizer_default_values[$name]);
        } else {
            return cosmecos_get_theme_mod($name);
        }
    }
}

// Get Prepared Color
if ( !function_exists('cosmecos_get_prepared_option') ) {
    function cosmecos_get_prepared_option( $name = '', $default = '', $dependency = '' ) {
        $value = '';
        cosmecos_get_wc_endpoint_page_id();

        if ( !empty($name) ) {
            if ( !empty($dependency) ) {
                if (
                    cosmecos_get_post_option($dependency) == 'on' &&
                    !empty(cosmecos_get_post_option($name))
                ) {
                    $value = cosmecos_get_post_option($name);
                } elseif (
                    cosmecos_get_theme_mod($dependency) == 'on' &&
                    !empty(cosmecos_get_theme_mod($name))
                ) {
                    $value = cosmecos_get_theme_mod($name);
                } elseif ( !empty($default) ) {
                    $value = cosmecos_get_prefered_option($default);
                }
            } else {
                $value = cosmecos_get_prefered_option($name);
            }
        }

        return $value;
    }
}

// Get Prepared Image
if ( !function_exists('cosmecos_get_prepared_img_url') ) {
    function cosmecos_get_prepared_img_url( $name = '', $dependency = '' ) {
        $img_url = '';

        if ( !empty($name) ) {
            if ( !empty($dependency) ) {
                if (
                    cosmecos_get_post_option($dependency) == 'on' &&
                    !empty(cosmecos_get_post_option($name)) &&
                    class_exists('RWMB_Loader')
                ) {
                    $img_metadata = rwmb_meta( $name, array( 'size' => 'full', 'limit' => 1 ) );
                    $image = reset( $img_metadata );
                    $img_url = $image['url'];
                } else {
                    $img_url = cosmecos_get_theme_mod($name);
                }
            } else {
                if ( !empty(cosmecos_get_post_option($name)) && class_exists('RWMB_Loader') ) {
                    $img_metadata = rwmb_meta( $name, array( 'size' => 'full', 'limit' => 1 ) );
                    $image = reset( $img_metadata );
                    $img_url = $image['url'];
                } else {
                    $img_url = cosmecos_get_theme_mod($name);
                }
            }
        }

        return esc_url($img_url);
    }
}

// Admin Footer
add_filter('admin_footer', 'cosmecos_admin_footer');
if (!function_exists('cosmecos_admin_footer')) {
    function cosmecos_admin_footer() {
        if (strlen(get_page_template_slug())>0) {
            echo "<input type='hidden' name='' value='" . (get_page_template_slug() ? get_page_template_slug() : '') . "' class='cosmecos_this_template_file'>";
        }
    }
}

if (!function_exists('cosmecos_remove_post_format_parameter')) {
    function cosmecos_remove_post_format_parameter($url) {
        $url = remove_query_arg('post_format', $url);
        return $url;
    }
    add_filter('preview_post_link', 'cosmecos_remove_post_format_parameter', 9999);
}

if (!function_exists('cosmecos_objectToArray')) {
    function cosmecos_objectToArray ($object) {
        if(!is_object($object) && !is_array($object))
            return $object;

        return array_map('cosmecos_objectToArray', (array) $object);
    }
}

// Output Code
if (!function_exists('cosmecos_output_code')) {
    function cosmecos_output_code($code) {
        return $code;
    }
}

// Shop Classes
add_filter( 'body_class', 'cosmecos_shop_classes' );
if (!function_exists('cosmecos_shop_classes')) {
    function cosmecos_shop_classes($classes) {
        if (class_exists('WooCommerce')) {
            if (is_shop()) {
                $classes[] = 'cosmecos-shop-list-page';
            } elseif (is_product()) {
                $classes[] = 'cosmecos-single-product-page';
            }
        }
        return $classes;
    }
}

// Filter for widgets
if (!function_exists('cosmecos_dynamic_sidebar_params')) {
    function cosmecos_dynamic_sidebar_params($sidebar_params) {
        if (is_admin()) {
            return $sidebar_params;
        }
        global $wp_registered_widgets;
        $widget_id = $sidebar_params[0]['widget_id'];
        $wp_registered_widgets[$widget_id]['original_callback'] = $wp_registered_widgets[$widget_id]['callback'];
        $wp_registered_widgets[$widget_id]['callback'] = 'cosmecos_widget_callback_function';

        return $sidebar_params;
    }
}
add_filter( 'dynamic_sidebar_params', 'cosmecos_dynamic_sidebar_params' );

if (!function_exists('cosmecos_widget_callback_function')) {
    function cosmecos_widget_callback_function() {
        global $wp_registered_widgets;
        $original_callback_params = func_get_args();
        $widget_id = $original_callback_params[0]['widget_id'];

        $original_callback = $wp_registered_widgets[$widget_id]['original_callback'];
        $wp_registered_widgets[$widget_id]['callback'] = $original_callback;

        $widget_id_base = $wp_registered_widgets[$widget_id]['callback'][0]->id_base;

        if (is_callable($original_callback)) {

            ob_start();
            call_user_func_array($original_callback, $original_callback_params);
            $widget_output = ob_get_clean();

            echo apply_filters('widget_output', $widget_output, $widget_id_base, $widget_id);

        }
    }
}

if (!function_exists('cosmecos_output_filter')) {
    function cosmecos_output_filter($widget_output, $widget_id_base, $widget_id) {
        if ($widget_id_base != 'woocommerce_product_categories' && $widget_id_base != 'wpforms-widget') {
            $widget_output = str_replace('<select', '<div class="select-wrap"><select', $widget_output);
            $widget_output = str_replace('</select>', '</select></div>', $widget_output);
        }

        return $widget_output;
    }
}
add_filter( 'widget_output', 'cosmecos_output_filter', 10, 3 );

// Get sidebar args
if ( !function_exists('cosmecos_get_sidebar_args') ) {
    function cosmecos_get_sidebar_args() {
        $additional_class = ' simple-sidebar';
        if (
            // is WooCommerce catalog
            class_exists('WooCommerce') &&
            is_woocommerce() &&
            ( is_shop() || is_product_category() || is_product_taxonomy() || is_product_tag() )
        ) {
            $sidebar_name = 'sidebar-woocommerce';
            $sidebar_position = cosmecos_get_prefered_option('catalog_sidebar_position');
            $additional_class = ' shop-hidden-sidebar';
        } elseif (
            // is archive page
            is_archive()
        ) {
            $sidebar_name = 'sidebar-archive';
            $sidebar_position = cosmecos_get_prefered_option('archive_sidebar_position');
        } elseif (
            // is single post page
            get_post_type() == 'post' &&
            ( is_single() ||  is_attachment() )
        ) {
            $sidebar_name = ( cosmecos_get_post_option('post_sidebar_select') != 'default' && !empty(cosmecos_get_post_option('post_sidebar_select')) ? cosmecos_get_post_option('post_sidebar_select') : 'sidebar-post' );
            $sidebar_position = cosmecos_get_prefered_option('post_sidebar_position');
        } elseif (
            // is portfolio single page
            get_post_type() == 'cosmecos-portfolio'
        ) {
            $sidebar_name = '';
            $sidebar_position = 'none';
        } elseif (
            // is team member page
            get_post_type() == 'cosmecos-team'
        ) {
            $sidebar_name = 'sidebar-team';
            $sidebar_position = cosmecos_get_prefered_option('team_sidebar_position');
        } elseif (
            // is regular page
            is_page() && !(class_exists('WooCommerce') && function_exists( 'yith_plugin_registration_hook' ) && yith_wcwl_is_wishlist_page())
        ) {
            $sidebar_name = ( cosmecos_get_post_option('page_sidebar_select') != 'default' && !empty(cosmecos_get_post_option('page_sidebar_select')) ? cosmecos_get_post_option('page_sidebar_select') : 'sidebar' );
            $sidebar_position = cosmecos_get_prefered_option('sidebar_position');
        } elseif (
            // is home page with latest posts
            is_home()
        ) {
            $sidebar_name = 'sidebar';
            $sidebar_position = cosmecos_get_prefered_option('sidebar_position');
        } else {
            $sidebar_name = 'sidebar';
            $sidebar_position = 'none';
        }
        $args['sidebar_name'] = $sidebar_name;
        $args['sidebar_position'] = ( is_active_sidebar($sidebar_name) ? $sidebar_position : 'none' );
        $args['additional_class'] = ( is_active_sidebar($sidebar_name) ? $additional_class : '' );
        return $args;
    }
}

// Get all menu list
if ( !function_exists('cosmecos_get_all_menu_list') ) {
    function cosmecos_get_all_menu_list() {
        $menu_list_default = array(
            'default' => esc_html__('Default', 'cosmecos')
        );
        $menu_list = array();
        $menus = wp_get_nav_menus();
        if ( !empty($menus) ) {
            foreach ($menus as $menu) {
                $menu_list[$menu->term_id] = $menu->name;
            }
        }
        $menu_list = $menu_list_default + $menu_list;
        return $menu_list;
    }
}

// Get all sidebar list
if ( !function_exists('cosmecos_get_all_sidebar_list') ) {
    function cosmecos_get_all_sidebar_list() {
        $sidebar_list = array();
        foreach ( $GLOBALS['wp_registered_sidebars'] as $sidebar ) {
            $sidebar_list[$sidebar['id']] = $sidebar['name'];
        }
        return $sidebar_list;
    }
}

// Phone number formatting
if ( !function_exists('cosmecos_clear_phone') ) {
    function cosmecos_clear_phone($string) {
        $string = '+' . preg_replace('~\D+~','', $string);
        return $string;
    }
}

// Get All Fonts Name
if (!function_exists('cosmecos_get_all_fonts_name')) {
    function cosmecos_get_all_fonts_name()
    {
        global $cosmecos_fonts_array;

        if (is_array($cosmecos_fonts_array['items'])) {
            foreach ($cosmecos_fonts_array['items'] as $key => $font) {
                $font_names[$font['family']] = $font['family'];
            }
        }

        return $font_names;
    }
}

// Get Current Fonts Array
if (!function_exists('cosmecos_get_current_fonts_array')) {
    function cosmecos_get_current_fonts_array() {
        $fonts_array = array();

        # Menu Font
        $fonts_array[cosmecos_get_theme_mod('header_menu_font_family')] = ':100,200,300,400,500,600,700,800,900,' . cosmecos_get_theme_mod('header_menu_font_weight');

        # Sub Menu Font
        $fonts_array[cosmecos_get_theme_mod('header_sub_menu_font_family')] = ':100,200,300,400,500,600,700,800,900,' . cosmecos_get_theme_mod('header_sub_menu_font_weight');

        # Page Title Font
        $fonts_array[cosmecos_get_theme_mod('page_title_heading_font_family')] = ':100,200,300,400,500,600,700,800,900,' . cosmecos_get_theme_mod('page_title_heading_font_weight');

        # Main Font
        $fonts_array[cosmecos_get_theme_mod('main_font_family')] = ':100,200,300,400,500,600,700,800,900,' . cosmecos_get_theme_mod('main_font_weight');

        # Additional Font
        $fonts_array[cosmecos_get_theme_mod('additional_font_family')] = ':100,200,300,400,500,600,700,800,900,' . cosmecos_get_theme_mod('additional_font_weight');

        # Headings Font
        $fonts_array[cosmecos_get_theme_mod('headings_font_family')] = ':100,200,300,400,500,600,700,800,900,';

        # Buttons Font
        $fonts_array[cosmecos_get_theme_mod('buttons_font_family')] = ':100,200,300,400,500,600,700,800,900,' . cosmecos_get_theme_mod('buttons_font_weight');

        return $fonts_array;
    }
}