<?php
/*
 * Created by Artureanec
*/

# Get Portfolio Post Categories in Post Navigation
function cosmecos_get_portfolio_nav_categories( $pid = '' ){
    $pid = empty($pid) ? get_the_id() : $pid;
    $terms_arr = wp_get_post_terms( $pid, 'portfolio-category' );
    $terms = "";
    if ( is_wp_error( $terms_arr ) ){
        return $terms;
    }
    for( $i = 0; $i < count( $terms_arr ); $i++ ){
        $term_obj	= $terms_arr[$i];
        $term_slug	= $term_obj->slug;
        $term_name	= esc_html( $term_obj->name );
        $term_link	= esc_url( get_term_link( $term_slug, 'portfolio-category' ) );
        $terms		.= "<a href='$term_link'>$term_name</a>" . ( $i < ( count( $terms_arr ) - 1 ) ? ", " : "" );
    }
    return $terms;
}

# Get Featured Image Url
if (!function_exists('cosmecos_get_featured_image_url')) {
    function cosmecos_get_featured_image_url() {
        $featured_image_full_url = wp_get_attachment_image_src(get_post_thumbnail_id(), 'full');
        if (isset($featured_image_full_url[0]) && strlen($featured_image_full_url[0]) > 0) {
            return esc_url($featured_image_full_url[0]);
        } else {
            return false;
        }
    }
}

if (!function_exists('cosmecos_get_attachment_meta')) {
    function cosmecos_get_attachment_meta($attachment_id) {
        $attachment = get_post($attachment_id);
        return array(
            'alt'           => get_post_meta($attachment->ID, '_wp_attachment_image_alt', true),
            'caption'       => $attachment->post_excerpt,
            'description'   => $attachment->post_content,
            'href'          => get_permalink($attachment->ID),
            'src'           => $attachment->guid,
            'title'         => $attachment->post_title
        );
    }
}

# Social Links Output
if (!function_exists('cosmecos_socials_output')) {
    function cosmecos_socials_output($container_class = '') {

        $socials_output = '<ul' . (!empty($container_class) ? ' class="' . esc_attr($container_class) . '">' : '>');

        if (cosmecos_get_theme_mod('socials_target')) {
            $socials_target = '_blank';
        } else {
            $socials_target = '_self';
        }

        # Twitter
        if (cosmecos_get_theme_mod('socials_twitter') !== '') {
            $socials_output .= '
                <li>
                    <a href="' . esc_url(cosmecos_get_theme_mod('socials_twitter')) . '" target="' . esc_attr($socials_target) . '" class="icon-twitter"></a>
                </li>
            ';
        }

        # Facebook
        if (cosmecos_get_theme_mod('socials_facebook') !== '') {
            $socials_output .= '
                <li>
                    <a href="' . esc_url(cosmecos_get_theme_mod('socials_facebook')) . '" target="' . esc_attr($socials_target) . '" class="icon-facebook"></a>
                </li>
            ';
        }

        # LinkedIn
        if (cosmecos_get_theme_mod('socials_linkedin') !== '') {
            $socials_output .= '
                <li>
                    <a href="' . esc_url(cosmecos_get_theme_mod('socials_linkedin')) . '" target="' . esc_attr($socials_target) . '" class="icon-linkedin"></a>
                </li>
            ';
        }

        # YouTube
        if (cosmecos_get_theme_mod('socials_youtube') !== '') {
            $socials_output .= '
                <li>
                    <a href="' . esc_url(cosmecos_get_theme_mod('socials_youtube')) . '" target="' . esc_attr($socials_target) . '" class="icon-youtube"></a>
                </li>
            ';
        }

        # Instagram
        if (cosmecos_get_theme_mod('socials_instagram') !== '') {
            $socials_output .= '
                <li>
                    <a href="' . esc_url(cosmecos_get_theme_mod('socials_instagram')) . '" target="' . esc_attr($socials_target) . '" class="icon-instagram"></a>
                </li>
            ';
        }

        # Pinterest
        if (cosmecos_get_theme_mod('socials_pinterest') !== '') {
            $socials_output .= '
                <li>
                    <a href="' . esc_url(cosmecos_get_theme_mod('socials_pinterest')) . '" target="' . esc_attr($socials_target) . '" class="icon-pinterest"></a>
                </li>
            ';
        }

        # Tumblr
        if (cosmecos_get_theme_mod('socials_tumbl') !== '') {
            $socials_output .= '
                <li>
                    <a href="' . esc_url(cosmecos_get_theme_mod('socials_tumbl')) . '" target="' . esc_attr($socials_target) . '" class="icon-tumblr"></a>
                </li>
            ';
        }

        # Flickr
        if (cosmecos_get_theme_mod('socials_flickr') !== '') {
            $socials_output .= '
                <li>
                    <a href="' . esc_url(cosmecos_get_theme_mod('socials_flickr')) . '" target="' . esc_attr($socials_target) . '" class="icon-flickr"></a>
                </li>
            ';
        }

        # VK
        if (cosmecos_get_theme_mod('socials_vk') !== '') {
            $socials_output .= '
                <li>
                    <a href="' . esc_url(cosmecos_get_theme_mod('socials_vk')) . '" target="' . esc_attr($socials_target) . '" class="icon-vk"></a>
                </li>
            ';
        }

        # Dribbble
        if (cosmecos_get_theme_mod('socials_dribbble') !== '') {
            $socials_output .= '
                <li>
                    <a href="' . esc_url(cosmecos_get_theme_mod('socials_dribbble')) . '" target="' . esc_attr($socials_target) . '" class="icon-dribbble"></a>
                </li>
            ';
        }

        # Vimeo
        if (cosmecos_get_theme_mod('socials_vimeo') !== '') {
            $socials_output .= '
                <li>
                    <a href="' . esc_url(cosmecos_get_theme_mod('socials_vimeo')) . '" target="' . esc_attr($socials_target) . '" class="icon-vimeo"></a>
                </li>
            ';
        }

        # 500px
        if (cosmecos_get_theme_mod('socials_500px') !== '') {
            $socials_output .= '
                <li>
                    <a href="' . esc_url(cosmecos_get_theme_mod('socials_500px')) . '" target="' . esc_attr($socials_target) . '" class="icon-500px"></a>
                </li>
            ';
        }

        # XING
        if (cosmecos_get_theme_mod('socials_xing') !== '') {
            $socials_output .= '
                <li>
                    <a href="' . esc_url(cosmecos_get_theme_mod('socials_xing')) . '" target="' . esc_attr($socials_target) . '" class="icon-xing"></a>
                </li>
            ';
        }

        # TikTok
        if (cosmecos_get_theme_mod('socials_tiktok') !== '') {
            $socials_output .= '
                <li>
                    <a href="' . esc_url(cosmecos_get_theme_mod('socials_tiktok')) . '" target="' . esc_attr($socials_target) . '" class="icon-tiktok"></a>
                </li>
            ';
        }

        $socials_output .= '</ul>';

        return $socials_output;
    }
}

// Breadcrumbs
if ( ! function_exists( 'cosmecos_breadcrumbs' ) ) {
    function cosmecos_breadcrumbs(){
        /* === OPTIONS === */
        $text['home']	    = esc_html__( 'Home', 'cosmecos' ); // text for the 'Home' link
        $text['category']   = esc_html__( 'Archive by Category "%s"', 'cosmecos' ); // text for a category page
        $text['search']     = esc_html__( 'Search for "%s"', 'cosmecos' ); // text for a search results page
        $text['taxonomy']   = esc_html__( 'Archive by %s "%s"', 'cosmecos' );
        $text['tag']	    = esc_html__( 'Posts Tagged "%s"', 'cosmecos' ); // text for a tag page
        $text['author']     = esc_html__( 'Articles Posted by %s', 'cosmecos' ); // text for an author page
        $text['404']	    = esc_html__( '404 Page', 'cosmecos' ); // text for the 404 page

        $show_current       = 1; // 1 - show current post/page/category title in breadcrumbs, 0 - don't show
        $show_on_home       = 0; // 1 - show breadcrumbs on the homepage, 0 - don't show
        $show_on_404   	    = 0; // 1 - show breadcrumbs on the 404, 0 - don't show
        $show_home_link     = 1; // 1 - show the 'Home' link, 0 - don't show
        $delimiter	        = "<span class='delimiter'></span>";
        $before		        = '<span class="current">'; // tag before the current crumb
        $after		        = '</span>'; // tag after the current crumb
        /* === END OF OPTIONS === */

        global $post;
        $home_link = esc_url( home_url( '/' ) );
        $link = '<a href="%1$s">%2$s</a>';
        $parent_id = '';
        if ( isset( $post->post_parent ) ) {
            $parent_id	= $parent_id_2 = $post->post_parent;
        }

        $frontpage_id = get_option( 'page_on_front' );

        if ( !$show_on_404 && is_404() ) {
            return;
        }

        if ( is_home() || is_front_page() ) {
            if ( $show_on_home == 1 ) {
                echo '<nav class="breadcrumbs"><a href="' . $home_link . '">' . $text['home'] . '</a></nav>';
            }
        } else if ( class_exists('WooCommerce') && is_woocommerce() ) {
            woocommerce_breadcrumb(array(
                'delimiter' => $delimiter,
                'wrap_before' => '<nav class="breadcrumbs">',
                'wrap_after' => '</nav>'
            ));
        } else {
            echo '<nav class="breadcrumbs">';
            if ( $show_home_link == 1 ) {
                echo '<a href="' . $home_link . '">' . $text['home'] . '</a>';
                if ( $frontpage_id == 0 || $parent_id != $frontpage_id ) { echo sprintf("%s", $delimiter ); }
            }

            if ( is_category() ) {
                $cat = get_category( get_query_var( 'cat' ) );
                $cat_name = isset( $cat->name ) ? $cat->name : '';
                $parent_cats = array();
                $has_parent_cat = false;
                $temp_cat = $cat;
                while ( true ) {
                    if ( isset( $temp_cat->parent ) && $temp_cat->parent ) {
                        array_push( $parent_cats, $temp_cat->parent );
                        $temp_cat = get_category( $temp_cat->parent );
                    } else {
                        break;
                    }
                }
                $parent_cats = array_reverse( $parent_cats );
                for ( $i = 0; $i < count( $parent_cats ); $i++ ) {
                    $cur_cat_obj = get_category( $parent_cats[ $i ] );
                    $cur_cat_name = isset( $cur_cat_obj->name ) ? $cur_cat_obj->name : '';
                    if ( ! empty( $cur_cat_name ) && isset( $cur_cat_obj->term_id ) ) {
                        $cur_cat_link = get_category_link( $cur_cat_obj->term_id );
                        if($has_parent_cat){
                            echo sprintf("%s", $delimiter);
                        }
                        printf( $link, $cur_cat_link, $cur_cat_name );
                        $has_parent_cat = true;
                    }
                }
                if ( $show_current == 1 ) {
                    if($has_parent_cat){
                        echo sprintf("%s", $delimiter);
                    }
                    echo sprintf("%s", $before) . sprintf( $text['category'], $cat_name );
                }
            } elseif ( is_tag() ) {
                echo sprintf("%s", $before) . sprintf( $text['tag'], single_tag_title( '', false ) ) . sprintf( "%s", $after );
            } elseif ( is_author() ) {
                global $author;
                $userdata = get_userdata( $author );
                echo sprintf("%s", $before) . esc_html( sprintf( $text['author'], $userdata->display_name ) ) . sprintf( "%s", $after );

            } elseif ( is_day() ) {
                echo sprintf( $link, get_year_link( get_the_time( 'Y' ) ), get_the_time( 'Y' ) ) . sprintf("%s", $delimiter);
                echo sprintf( $link, get_month_link( get_the_time( 'Y' ),get_the_time( 'm' ) ), get_the_time( 'F' ) ) . sprintf("%s", $delimiter);
                echo sprintf("%s", $before) . get_the_time( 'd' ) . sprintf( "%s", $after );

            } elseif ( is_month() ) {
                echo sprintf( $link, get_year_link( get_the_time( 'Y' ) ), get_the_time( 'Y' ) ) . sprintf("%s", $delimiter);
                echo sprintf("%s", $before) . get_the_time( 'F' ) . sprintf( "%s", $after );

            } elseif ( is_year() ) {
                echo sprintf("%s", $before) . get_the_time( 'Y' ) . sprintf( "%s", $after );

            } elseif ( has_post_format() && ! is_singular() ) {
                echo get_post_format_string( get_post_format() );
            } else if ( is_tax( array( 'cosmecos-portfolio', 'portfolio-category', 'cosmecos-team', 'team-category' ) ) ) {
                $tax_slug = get_query_var( 'taxonomy' );
                $term_slug = get_query_var( $tax_slug );
                $tax_obj = get_taxonomy( $tax_slug );
                $term_obj = get_term_by( 'slug', $term_slug, $tax_slug );
                $parent_terms = array();
                $has_parent_term = false;
                if ( isset( $tax_obj->hierarchical ) && $tax_obj->hierarchical ) {
                    $temp_term_obj = $term_obj;
                    while ( true ) {
                        if ( isset( $temp_term_obj->parent ) && $temp_term_obj->parent ) {
                            array_push( $parent_terms, $temp_term_obj->parent );
                            $temp_term_obj = get_term_by( 'id', $temp_term_obj->parent, $tax_slug );
                        } else {
                            break;
                        }
                    }
                    $parent_terms = array_reverse( $parent_terms );
                    for ( $i = 0; $i < count( $parent_terms ); $i++ ) {
                        $cur_term = get_term_by( 'id', $parent_terms[ $i ], $tax_slug );
                        $cur_term_name = isset( $cur_term->name ) ? $cur_term->name : '';
                        if ( ! empty( $cur_term_name ) && isset( $cur_term->term_id ) ) {
                            $cur_term_link = get_term_link( $cur_term->term_id, $tax_slug );
                            if($has_parent_term){
                                echo sprintf("%s", $delimiter);
                            }
                            printf( $link, $cur_term_link, $cur_term_name );
                            $has_parent_term = true;
                        }
                    }
                }
                if ( $show_current == 1 ) {
                    $singular_tax_label = isset( $tax_obj->labels ) && isset( $tax_obj->labels->singular_name ) ? $tax_obj->labels->singular_name : '';
                    $term_name = isset( $term_obj->name ) ? $term_obj->name : '';
                    if($has_parent_term){
                        echo sprintf("%s", $delimiter);
                    }
                    echo sprintf("%s", $before) . esc_html( sprintf( $text['taxonomy'], $singular_tax_label, $term_name ) );
                }
            } elseif ( is_archive() ) {
                if ( $show_current ) {
                    $post_type = get_post_type();
                    $post_type_obj = get_post_type_object( $post_type );

                    if( $post_type == 'cosmecos-portfolio' || $post_type == 'cosmecos-team' ){
                        $post_type_name = get_theme_mod($post_type.'_slug');
                    }

                    if( empty($post_type_name) ){
                        $post_type_name = isset( $post_type_obj->label ) ? $post_type_obj->label : '';
                    }

                    echo sprintf("%s", $before) . esc_html($post_type_name) . sprintf( "%s", $after );
                }
            } elseif ( is_search() ) {
                echo sprintf("%s", $before) . sprintf( $text['search'], get_search_query() ) . sprintf( "%s", $after );
            } elseif ( is_single() ) {
                $post_type = get_post_type();
                $post_type_obj = get_post_type_object( $post_type );

                if( $post_type == 'cosmecos-portfolio' || $post_type == 'cosmecos-team' ){
                    $post_type_label = get_theme_mod($post_type.'_slug');
                }

                if( empty($post_type_label) ){
                    $post_type_label = isset( $post_type_obj->label ) ? $post_type_obj->label : '';
                }

                $post_type_link = get_post_type_archive_link( $post_type );
                if ( $post_type_obj->has_archive ) {
                    printf( $link, $post_type_link, $post_type_label  );
                    echo sprintf("%s", $delimiter);
                }

                if ( $show_current ) {
                    if ( empty(get_the_title()) ) {
                        echo sprintf("%s", $before) . esc_html__('(no title)', 'cosmecos') . sprintf("%s", $after);
                    } else {
                        echo sprintf("%s", $before) . wp_kses( get_the_title(), array(
                                "b"			=> array(),
                                "em"		=> array(),
                                "sup"		=> array(),
                                "sub"		=> array(),
                                "strong"	=> array(),
                                "mark"		=> array(),
                                "br"		=> array()
                            )) . sprintf("%s", $after);
                    }
                }
            } elseif ( is_page() && ! $parent_id ) {
                if ( empty(get_the_title()) ) {
                    echo sprintf("%s", $before) . esc_html__('(no title)', 'cosmecos') . sprintf("%s", $after);
                } else {
                    echo sprintf("%s", $before) . wp_kses( get_the_title(), array(
                            "b"			=> array(),
                            "em"		=> array(),
                            "sup"		=> array(),
                            "sub"		=> array(),
                            "strong"	=> array(),
                            "mark"		=> array(),
                            "br"		=> array()
                        )) . sprintf("%s", $after);
                }
            } elseif ( is_page() && $parent_id ) {
                if ( $parent_id != $frontpage_id ) {
                    $breadcrumbs = array();
                    while ( $parent_id ) {
                        $page = get_page( $parent_id );
                        if ( $parent_id != $frontpage_id ) {
                            $breadcrumbs[] = sprintf( $link, get_permalink( $page->ID ), wp_kses( get_the_title( $page->ID ), array(
                                "b"			=> array(),
                                "em"		=> array(),
                                "sup"		=> array(),
                                "sub"		=> array(),
                                "strong"	=> array(),
                                "mark"		=> array(),
                                "br"		=> array()
                            )) );
                        }
                        $parent_id = $page->post_parent;
                    }
                    $breadcrumbs = array_reverse( $breadcrumbs );
                    for ( $i = 0; $i < count( $breadcrumbs ); $i++ ) {
                        echo sprintf("%s", $breadcrumbs[ $i ]);
                        if ( $i != count( $breadcrumbs ) -1 ) { echo sprintf("%s", $delimiter); }
                    }
                }
                if ( $show_current == 1 ) {
                    if ( $show_home_link == 1 || ($parent_id_2 != 0 && $parent_id_2 != $frontpage_id) ) { echo sprintf("%s", $delimiter); }
                    if ( empty(get_the_title()) ) {
                        echo sprintf("%s", $before) . esc_html__('(no title)', 'cosmecos') . sprintf("%s", $after);
                    } else {
                        echo sprintf("%s", $before) . wp_kses( get_the_title(), array(
                                "b"			=> array(),
                                "em"		=> array(),
                                "sup"		=> array(),
                                "sub"		=> array(),
                                "strong"	=> array(),
                                "mark"		=> array(),
                                "br"		=> array()
                            )) . sprintf("%s", $after);
                    }
                }
            } elseif ( is_404() ) {
                echo sprintf("%s", $before) . esc_html($text['404']) . sprintf( "%s", $after );
            }

            if ( get_query_var( 'paged' ) ) {
                echo sprintf("%s", $delimiter) . esc_html__( 'Page', 'cosmecos' ) . ' ' . get_query_var( 'paged' );
            }
            echo '</nav>';
        }
    }
}

// Single Post Media Output
if (!function_exists('cosmecos_post_media_output')) {
    function cosmecos_post_media_output($link = false, $columns = 1) {
        $post_format    = get_post_format();
        switch ( $columns ) {
            case 2:
                $max_width = 920;
                $max_height = 780;
                $img_size_desktop = 'cosmecos_post_grid_2_columns';
                $img_size_mobile = 'cosmecos_post_thumbnail_mobile';
                $img_size_table = 'cosmecos_post_grid_4_columns';
                break;
            case 3:
                $max_width = 600;
                $max_height = 510;
                $img_size_desktop = 'cosmecos_post_grid_3_columns';
                $img_size_mobile = 'cosmecos_post_thumbnail_mobile';
                $img_size_table = 'cosmecos_post_grid_4_columns';
                break;
            case 4:
                $max_width = 440;
                $max_height = 374;
                $img_size_desktop = 'cosmecos_post_grid_4_columns';
                $img_size_mobile = 'cosmecos_post_thumbnail_mobile';
                $img_size_table = 'cosmecos_post_grid_4_columns';
                break;
            case 5:
                $max_width = 344;
                $max_height = 292;
                $img_size_desktop = 'cosmecos_post_grid_5_columns';
                $img_size_mobile = 'cosmecos_post_thumbnail_mobile';
                $img_size_table = 'cosmecos_post_grid_4_columns';
                break;
            case 6:
                $max_width = 280;
                $max_height = 238;
                $img_size_desktop = 'cosmecos_post_grid_6_columns';
                $img_size_mobile = 'cosmecos_post_thumbnail_mobile';
                $img_size_table = 'cosmecos_post_grid_4_columns';
                break;
            default:
                $max_width = 1170;
                $max_height = 538;
                $img_size_desktop = 'post-thumbnail';
                $img_size_mobile = 'cosmecos_post_thumbnail_mobile';
                $img_size_table = 'cosmecos_post_thumbnail_tablet';
        }
        if ( empty($post_format) ) {
            $post_format = 'standard';
        }
        if (
            $post_format == 'video' && cosmecos_post_options() && class_exists('RWMB_Loader') &&
            (
                ( cosmecos_get_post_option('post_media_video_type') == 'link' && !empty(cosmecos_get_post_option('post_media_video_url')) ) ||
                ( cosmecos_get_post_option('post_media_video_type') == 'self' && !empty(cosmecos_get_post_option('post_media_video_select')) )
            )
        ) {
            $poster_id = get_post_thumbnail_id();
            $poster_src = wp_get_attachment_image_url($poster_id, $img_size_desktop);
            if (cosmecos_get_post_option('post_media_video_type') == 'link' && !empty(cosmecos_get_post_option('post_media_video_url'))) {
                $out = wp_video_shortcode(array(
                    'src'       => rwmb_get_value('post_media_video_url'),
                    'height'    => $max_height,
                    'width'     => $max_width,
                    'poster'    => $poster_src
                ), '');
            } elseif (cosmecos_get_post_option('post_media_video_type') == 'self' && !empty(cosmecos_get_post_option('post_media_video_select'))) {
                $videos = rwmb_meta('post_media_video_select');
                foreach ($videos as $video) {
                    $out = wp_video_shortcode(array(
                        'src'       => $video['src'],
                        'height'    => $max_height,
                        'width'     => $max_width,
                        'poster'    => $poster_src
                    ), '');
                }
            }
        } elseif ( $post_format == 'gallery' && cosmecos_post_options() && class_exists('RWMB_Loader') && !empty(cosmecos_get_post_option('post_media_gallery_select')) && is_array(cosmecos_get_post_option('post_media_gallery_select')) ) {
            $out = '<div class="wp-post-gallery post-gallery-carousel owl-carousel owl-theme">';
            foreach (cosmecos_get_post_option('post_media_gallery_select') as $key => $image) {
                $src = $image['sizes'][$img_size_desktop]['url'];
                $title = $image['title'];
                $alt = !empty($image['alt']) ? $image['alt'] : $title;
                $out .= '<div class="item">';
                    $out .= '<picture>';
                        $out .= '<source media="(max-width: 575px)" sizes="(max-width: 535px) 535px" srcset="' . $image['sizes'][$img_size_mobile]['url'] . ' 535w">';
                        $out .= '<source media="(max-width: 991px)" sizes="(max-width: 951px) 951px" srcset="' . $image['sizes'][$img_size_table]['url'] . ' 951w">';
                        $out .= '<img alt="' . esc_attr($alt) . '" title="' . esc_attr($title) . '" src="' . esc_url($src) . '" class="attachment-' . esc_attr($img_size_desktop) . ' size-' . esc_attr($img_size_desktop) . ' wp-post-image" />';
                    $out .= '</picture>';
                $out .= '</div>';
            }
            $out .= '</div>';
        } elseif ( $post_format == 'quote' && cosmecos_post_options() && !empty(cosmecos_get_post_option('post_media_quote_text')) ) {
            $id = get_post_thumbnail_id();
            $src = wp_get_attachment_image_url($id, $img_size_desktop);
            if ( $src ) {
                $img_src_mobile = wp_get_attachment_image_url($id, $img_size_mobile);
                $img_src_tablet = wp_get_attachment_image_url($id, $img_size_table);
                $title = get_post($id)->post_title;
                $alt = ( !empty(get_post_meta($id, '_wp_attachment_image_alt', true)) ) ? get_post_meta($id, '_wp_attachment_image_alt', true) : $title;
            } else {
                $src = get_template_directory_uri() . '/img/bg-post-quote-1170x538.jpg';
                $img_src_mobile = get_template_directory_uri() . '/img/bg-post-quote-535x300.jpg';
                $img_src_tablet = get_template_directory_uri() . '/img/bg-post-quote-951x438.jpg';
                $title = esc_attr__('Quote', 'cosmecos');
                $alt = esc_attr__('Quote', 'cosmecos');
            }
            $out = $link ? '<a href="' . esc_url(get_the_permalink()) . '" class="post-quote">' : '<div class="post-quote">';
                $out .= '<picture>';
                    $out .= '<source media="(max-width: 575px)" sizes="(max-width: 535px) 535px" srcset="' . $img_src_mobile . ' 535w">';
                    $out .= '<source media="(max-width: 991px)" sizes="(max-width: 951px) 951px" srcset="' . $img_src_tablet . ' 951w">';
                    $out .= '<img alt="' . esc_attr($alt) . '" title="' . esc_attr($title) . '" src="' . esc_url($src) . '" class="attachment-' . esc_attr($img_size_desktop) . ' size-' . esc_attr($img_size_desktop) . ' wp-post-image" />';
                $out .= '</picture>';
                $out .= !empty(cosmecos_get_post_option('post_media_quote_text')) ? '<div class="post-quote-text">' . esc_html(cosmecos_get_post_option('post_media_quote_text')) . '</div>' : '';
                $out .= !empty(cosmecos_get_post_option('post_media_quote_author')) ? '<div class="post-quote-author">' . esc_html(cosmecos_get_post_option('post_media_quote_author')) . '</div>' : '';
            $out .= $link ? '</a>' : '</div>';
        } else {
            $id = get_post_thumbnail_id();
            $out = '';
            if ( $id ) {
                $src = wp_get_attachment_image_url($id, $img_size_desktop);
                $title = get_post($id)->post_title;
                $alt = ( !empty(get_post_meta($id, '_wp_attachment_image_alt', true)) ) ? get_post_meta($id, '_wp_attachment_image_alt', true) : $title;

                $out .= $link ? '<a href="' . esc_url(get_the_permalink()) . '">' : '';
                    $out .= '<picture>';
                        $out .= '<source media="(max-width: 575px)" sizes="(max-width: 535px) 535px" srcset="' . wp_get_attachment_image_url($id, $img_size_mobile) . ' 535w">';
                        $out .= '<source media="(max-width: 991px)" sizes="(max-width: 951px) 951px" srcset="' . wp_get_attachment_image_url($id, $img_size_table) . ' 951w">';
                        $out .= '<img alt="' . esc_attr($alt) . '" title="' . esc_attr($title) . '" src="' . esc_url($src) . '" class="attachment-' . esc_attr($img_size_desktop) . ' size-' . esc_attr($img_size_desktop) . ' wp-post-image" />';
                    $out .= '</picture>';
                $out .= $link ? '</a>' : '';
            }
        }

        return $out;
    }
}

// Single Portfolio Gallery Output
if (!function_exists('cosmecos_portfolio_media_output')) {
    function cosmecos_portfolio_media_output($link = false) {
        $out = '';
        if ( cosmecos_post_options() && class_exists('RWMB_Loader') && !empty(cosmecos_get_post_option('portfolio_gallery')) && is_array(cosmecos_get_post_option('portfolio_gallery')) ) {
            foreach (cosmecos_get_post_option('portfolio_gallery') as $key => $image) {
                $src = $image['sizes']['cosmecos_portfolio_thumbnail']['url'];
                $srcset = $image['sizes']['cosmecos_post_thumbnail_mobile']['url'] . ' 535w, ' . $src . ' 951w';
                $sizes = '(max-width: 575px) 535px';
                $title = $image['title'];
                $alt = !empty($image['alt']) ? $image['alt'] : $title;
                $out .= '<div class="portfolio-post-gallery-image-item"><img src="' . esc_url($src) . '" alt="' . esc_attr($alt) . '" title="' . esc_attr($title) . '" srcset="' . esc_attr($srcset) . '" sizes="' . esc_attr($sizes) . '" class="attachment-cosmecos_portfolio_thumbnail size-cosmecos_portfolio_thumbnail wp-post-image" /></div>';
            }
        } else {
            $id = get_post_thumbnail_id();
            $src = wp_get_attachment_image_url($id, 'cosmecos_portfolio_thumbnail');
            $srcset = wp_get_attachment_image_url($id, 'cosmecos_post_thumbnail_mobile') . ' 535w, ' . $src . ' 951w';
            $sizes = '(max-width: 575px) 535px';
            $title = get_post($id)->post_title;
            $alt = ( !empty(get_post_meta($id, '_wp_attachment_image_alt', true)) ) ? get_post_meta($id, '_wp_attachment_image_alt', true) : $title;
            $out = $link ? '<a href="' . esc_url(get_the_permalink()) . '">' : '';
            $out .= '<div class="portfolio-post-gallery-image-item"><img alt="' . esc_attr($alt) . '" title="' . esc_attr($title) . '" srcset="' . esc_attr($srcset) . '" sizes="' . esc_attr($sizes) . '" src="' . esc_url($src) . '" class="attachment-cosmecos_portfolio_thumbnail size-cosmecos_portfolio_thumbnail wp-post-image" /></div>';
            $out .= $link ? '</a>' : '';
        }

        return $out;
    }
}

// Portfolio Grid Media Output
if ( !function_exists('cosmecos_portfolio_grid_media_output') ) {
    function cosmecos_portfolio_grid_media_output($post_id = null, $columns = 3, $is_masonry = false, $order = 1) {
        $out = '';
        $id = get_post_thumbnail_id($post_id);
        $title = get_post($id)->post_title;
        $alt = ( !empty(get_post_meta($id, '_wp_attachment_image_alt', true)) ) ? get_post_meta($id, '_wp_attachment_image_alt', true) : $title;
        if ( $is_masonry ) {
            if ( $order == 3 || $order == 6 ) {
                $img_size_desktop = 'cosmecos_portfolio_grid_2_columns';
                $img_size_mobile = 'cosmecos_portfolio_grid_3_columns';
                $img_size_table = 'cosmecos_portfolio_grid_4_columns';
            } else {
                $img_size_desktop = 'cosmecos_portfolio_grid_4_columns';
                $img_size_mobile = 'cosmecos_portfolio_grid_3_columns';
                $img_size_table = 'cosmecos_portfolio_grid_4_columns';
            }
        } else {
            switch ( $columns ) {
                case 2:
                    $img_size_desktop = 'cosmecos_portfolio_grid_2_columns';
                    $img_size_mobile = 'cosmecos_portfolio_grid_3_columns';
                    $img_size_table = 'cosmecos_portfolio_grid_4_columns';
                    break;
                case 3:
                    $img_size_desktop = 'cosmecos_portfolio_grid_3_columns';
                    $img_size_mobile = 'cosmecos_portfolio_grid_3_columns';
                    $img_size_table = 'cosmecos_portfolio_grid_5_columns';
                    break;
                case 4:
                    $img_size_desktop = 'cosmecos_portfolio_grid_4_columns';
                    $img_size_mobile = 'cosmecos_portfolio_grid_3_columns';
                    $img_size_table = 'cosmecos_portfolio_grid_4_columns';
                    break;
                case 5:
                    $img_size_desktop = 'cosmecos_portfolio_grid_5_columns';
                    $img_size_mobile = 'cosmecos_portfolio_grid_3_columns';
                    $img_size_table = 'cosmecos_portfolio_grid_4_columns';
                    break;
                case 6:
                    $img_size_desktop = 'cosmecos_portfolio_grid_6_columns';
                    $img_size_mobile = 'cosmecos_portfolio_grid_3_columns';
                    $img_size_table = 'cosmecos_portfolio_grid_5_columns';
                    break;
                default:
                    $img_size_desktop = 'cosmecos_portfolio_grid_1_columns';
                    $img_size_mobile = 'cosmecos_portfolio_grid_3_columns';
                    $img_size_table = 'cosmecos_portfolio_grid_2_columns';
            }
        }

        $src = wp_get_attachment_image_url($id, $img_size_desktop);
        $srcset = wp_get_attachment_image_url($id, $img_size_mobile) . ' 535w, ' . wp_get_attachment_image_url($id, $img_size_table) . ' 951w, ' . $src . ' 1170w';
        $sizes = '(max-width: 575px) 535px, (max-width: 991px) 951px';

        $out .= '<img alt="' . esc_attr($alt) . '" title="' . esc_attr($title) . '" srcset="' . esc_attr($srcset) . '" sizes="' . esc_attr($sizes) . '" src="' . esc_url($src) . '" class="attachment-' . esc_attr($img_size_desktop) . ' size-' . esc_attr($img_size_desktop) . ' wp-post-image" />';

        return $out;
    }
}

// Get all Blog Categories Array
if ( !function_exists('cosmecos_get_all_blog_categories') ) {
    function cosmecos_get_all_blog_categories() {
        $category_arr = [];
        $categories = get_categories(
            [
                'taxonomy'      => 'category',
                'type'          => 'post',
                'child_of'      => 0,
                'parent'        => '',
                'orderby'       => 'name',
                'order'         => 'ASC',
                'hierarchical'  => 1,
                'exclude'       => '',
                'include'       => '',
                'number'        => 0,
                'pad_counts'    => false
            ]
        );
        if( !empty($categories) ) {
            foreach ($categories as $key => $category) {
                $category_arr[$category->slug] = $category->name;
            }
        }

        return $category_arr;
    }
}

// Get Post Categories
if ( !function_exists('cosmecos_post_categories_output') ) {
    function cosmecos_post_categories_output( $link = false ) {
        $categories = get_the_category();
        $categ_code = array();
        if ( is_array($categories) && count($categories) > 0 ) {
            foreach ($categories as $category) {
                if ( $link ) {
                    $categ_code[] = '<a class="post-category-item" href="' . esc_url(get_category_link($category->cat_ID)) . '">' . esc_html($category->name) . '</a>';
                } else {
                    $categ_code[] = '<span class="post-category-item">' . esc_html($category->name) . '</span>';
                }
            }
            return '<div class="post-categories">' . join('', $categ_code) . '</div>';
        } else {
            return false;
        }
    }
};

// Get Portfolio Categories
if ( !function_exists('cosmecos_portfolio_categories_output') ) {
    function cosmecos_portfolio_categories_output( $id = null, $link = false, $label = false ) {
        $categories = get_the_terms( $id, 'portfolio-category' );
        $categ_code = array();
        if ( is_array($categories) && count($categories) > 0 ) {
            foreach ($categories as $category) {
                if ( $link ) {
                    $categ_code[] = '<a href="' . get_term_link($category->term_id) . '">' . esc_html($category->name) . '</a>';
                } else {
                    $categ_code[] = esc_html($category->name);
                }
            }
            if ( $label ) {
                return ( count($categ_code) > 1 ? esc_html__('Categories: ', 'cosmecos') : esc_html__('Category: ', 'cosmecos') ) . join(', ', $categ_code);
            } else {
                return join(', ', $categ_code);
            }
        } else {
            return false;
        }
    }
}

// Get all Portfolio Categories Array
if ( !function_exists('cosmecos_get_all_portfolio_list') ) {
    function cosmecos_get_all_portfolio_list() {
        $portfolio_list = [];
        $all_portfolio = get_posts(
            [
                'post_type'     => 'cosmecos-portfolio',
                'numberposts'   => '-1'
            ]
        );

        if ($all_portfolio > 0) {
            foreach ($all_portfolio as $portfolio) {
                setup_postdata($portfolio);
                $portfolio_list[$portfolio->ID] = $portfolio->post_title;
            }
        } else {
            $portfolio_list = array(
                'no_posts' => esc_html__('No Posts Were Found', 'cosmecos')
            );
        }

        return $portfolio_list;
    }
}

// Get all Blog Tags Array
if ( !function_exists('cosmecos_get_all_blog_tags') ) {
    function cosmecos_get_all_blog_tags() {
        $tags_arr = [];
        $tags = get_tags(
            [
                'taxonomy' => 'post_tag',
                'type' => 'post',
                'child_of' => 0,
                'parent' => '',
                'orderby' => 'name',
                'order' => 'ASC',
                'hierarchical' => 1,
                'exclude' => '',
                'include' => '',
                'number' => 0,
                'pad_counts' => false
            ]
        );
        if( !empty($tags) ) {
            foreach ($tags as $key => $tag) {
                $tags_arr[$tag->slug] = $tag->name;
            }
        }

        return $tags_arr;
    }
}

// Get Post Tags
if ( !function_exists('cosmecos_post_tags_output') ) {
    function cosmecos_post_tags_output($separator = '') {
        if ( !empty(get_the_tag_list()) ) {
            return get_the_tag_list('<div class="post-meta-item post-meta-item-tags">', $separator, '</div>');
        } else {
            return false;
        }
    }
};

// Get Post Date
if ( !function_exists('cosmecos_post_date_output') ) {
    function cosmecos_post_date_output( $link = false ) {
        if ( !empty(get_the_date()) ) {
            if ( $link ) {
                $date = '<a href="' . get_day_link(get_post_time('Y'), get_post_time('m'), get_post_time('j')) . '">' . get_the_date() . '</a>';
            } else {
                $date = get_the_date();
            }
            return '<div class="post-meta-item post-meta-item-date">' . wp_kses($date, array('a' => array('href' => true))) . '</div>';
        } else {
            return false;
        }
    }
};

// Get Post Author
if ( !function_exists('cosmecos_post_author_output') ) {
    function cosmecos_post_author_output( $link = false ) {
        if ( !empty(get_the_author_meta('display_name')) ) {
            if ( $link ) {
                $author = '<a href="' . esc_url(get_author_posts_url(get_the_author_meta('ID'), get_the_author_meta('nickname'))) . '">' . get_the_author_meta('display_name') . '</a>';
            } else {
                $author = get_the_author_meta('display_name');
            }
            return '<div class="post-meta-item post-meta-item-author">' . esc_html__('By', 'cosmecos') . ' ' . wp_kses($author, array('a' => array('href' => true))) . '</div>';
        } else {
            return false;
        }
    }
};

// Recent Posts
if (!function_exists('cosmecos_recent_posts_output')) {
    function cosmecos_recent_posts_output($args = array(
        'orderby'               => 'rand',
        'numberposts'           => '3',
        'post_type'             => 'post',
        'order'                 => 'desc',
        'show_media'            => 'on',
        'show_category'         => 'on',
        'show_title'            => 'on',
        'show_date'             => 'on',
        'show_author'           => 'on',
        'show_excerpt'          => 'off',
        'excerpt_length'        => '120',
        'show_tags'             => 'off',
        'show_more'             => 'on',
    )) {
        global $post;
        extract($args);

        $currentID = get_the_ID();
        $args = array(
            'post_type'             => $post_type,
            'post__not_in'          => array($currentID),
            'post_status'           => 'publish',
            'orderby'               => $orderby,
            'order'                 => $order,
            'posts_per_page'        => absint($numberposts),
            'ignore_sticky_posts'   => 1,
            'suppress_filters'      => false
        );

        $recent_posts = get_posts($args);

        $wrapper_class = ' archive-listing-wrapper grid-listing columns-' . esc_attr($numberposts);
        $item_class = 'post grid-item grid-blog-item-wrapper';

        if (!empty($recent_posts)) {
            echo '
                <div class="recent-posts-wrapper">
                    <div class="container">';

                        if ( cosmecos_get_prefered_option('recent_posts_customize') == 'on' ) {
                            if ( !empty(cosmecos_get_prepared_option('recent_posts_section_heading', '', 'recent_posts_customize')) ) {
                                echo '<h5 class="recent-posts-wrapper-title">';
                                    echo esc_html(cosmecos_get_prepared_option('recent_posts_section_heading', '', 'recent_posts_customize'));
                                echo '</h5>';
                            }
                        } else {
                            echo '<h5 class="recent-posts-wrapper-title">' . esc_html__('Recent Posts', 'cosmecos') . '</h5>';
                        }

                        echo '<div class="recent-posts' . esc_attr($wrapper_class) . '">';
            $i = 1;
            foreach( $recent_posts as $post ){
                setup_postdata($post);
                $post_format = get_post_format();
                $cosmecos_excerpt = substr(get_the_excerpt(), 0, $excerpt_length);

                echo '<div class="' . esc_attr($item_class) . '">';
                    echo '<div class="blog-item">';

                        if (
                            ( !empty(cosmecos_post_media_output()) && $show_media == 'on' ) ||
                            ( !empty(cosmecos_post_categories_output()) && $post_format != 'quote' && $show_category == 'on' )
                        ) {
                            echo '<div class="post-media-wrapper">';
                                if ( !empty(cosmecos_post_media_output()) && $show_media == 'on' ) {
                                    echo cosmecos_post_media_output(true, $numberposts);
                                }
                                echo '<div class="post-labels">';
                                if ( !empty(cosmecos_post_categories_output()) && $post_format != 'quote' && $show_category == 'on' ) {
                                    echo cosmecos_post_categories_output(true);
                                }
                                echo '</div>';
                            echo '</div>';
                        }

                        if ( !($post_format == 'quote' && cosmecos_post_options() && !empty(cosmecos_get_post_option('post_media_quote_text'))) ) {
                            if (
                                ( !empty(cosmecos_post_date_output()) && $show_date == 'on' ) ||
                                ( !empty(cosmecos_post_author_output()) && $show_author == 'on' )
                            ) {
                                echo '<div class="post-meta-header">';
                                    if ( !empty(cosmecos_post_date_output()) && $show_date == 'on' ) {
                                        echo cosmecos_post_date_output(true);
                                    }
                                    if ( !empty(cosmecos_post_author_output()) && $show_author == 'on' ) {
                                        echo cosmecos_post_author_output(true);
                                    }
                                echo '</div>';
                            }

                            if ( !empty(get_the_title()) && $show_title == 'on' ) {
                                echo '<h5 class="post-title"><a href="' . esc_url(get_the_permalink()) . '">' . get_the_title() . '</a></h5>';
                            }

                            if ( $show_excerpt == 'on' && !empty($cosmecos_excerpt) ) {
                                echo '<div class="post-content">' . esc_html($cosmecos_excerpt) . '</div>';
                            }

                            if ( !empty(cosmecos_post_tags_output()) && $show_tags == 'on' ) {
                                echo cosmecos_post_tags_output(', ');
                            }

                            if ($show_more == 'on') {
                                echo '<div class="post-more-button">';
                                    echo '<a href="' . esc_url(get_the_permalink()) . '">' . esc_html__('Read More', 'cosmecos') . '</a>';
                                echo '</div>';
                            }
                        }

                    echo '</div>';
                echo '</div>';

                $i++;
            }
            wp_reset_postdata();
            echo '
                        </div>
                    </div>
                </div>
            ';
        }
    }
}

// Get Post Navigation
if (!function_exists('cosmecos_post_navigation')) {
    function cosmecos_post_navigation() {
        $first_post_loop = get_posts( 'post_type='.get_post_type().'&numberposts=1&order=ASC' );
        $first_post = $first_post_loop[0];

        $last_post_loop = get_posts( 'post_type='.get_post_type().'&numberposts=1' );
        $last_post = $last_post_loop[0];

        $next_post = get_next_post() ? get_next_post() : $first_post;
        $prev_post = get_previous_post() ? get_previous_post() : $last_post;

        $out = '';

        if ( get_next_post() || get_previous_post() ) {
            $out .= '<nav class="navigation post-navigation">';
                $out .= '<ul class="post-navigation-list">';
                if ( $prev_post ) {
                    $out .= '<li class="post-navigation-item prev-post">';
                        $out .= '<div class="post-navigation-link">';
                            $out .= '<a href="' . get_permalink( $prev_post ) . '">';
                                $out .= esc_html__('Prev Post', 'cosmecos');
                            $out .= '</a>';
                        $out .= '</div>';
                        $out .= '<div class="post-navigation-block">';
                        $thumbnail = get_the_post_thumbnail_url($prev_post->ID, array(70, 70));
                        if ( !empty($thumbnail) ) {
                            $out .= '<a href="' . get_permalink($prev_post) . '" class="post-navigation-image">';
                                $out .= '<img src="' . esc_url($thumbnail) . '" alt="' . esc_attr($prev_post->post_title) . '"/>';
                            $out .= '</a>';
                        }
                        $out .= '<div class="post-navigation-content">';
                            $out .= '<div class="post-navigation-title">';
                                $out .= '<a href="' . get_permalink( $prev_post ) . '">';
                                    if ( function_exists('wpm') ) {
                                        $out .= wpm_translate_string(wp_kses_post( $prev_post->post_title ));
                                    } else {
                                        $out .= wp_kses_post( $prev_post->post_title );
                                    }
                                $out .= '</a>';
                            $out .= '</div>';
                            $prev_categories = cosmecos_portfolio_categories_output($prev_post->ID, true);
                            if( !empty($prev_categories) ) {
                                $out .= '<div class="post-navigation-categories">';
                                    $out .= sprintf('%s', $prev_categories);
                                $out .= '</div>';
                            }
                            $out .= '</div>';
                        $out .= '</div>';
                    $out .= '</li>';
                } else {
                    $out .= '<li class="post-navigation-item prev-post disabled"></li>';
                }

                if ( !empty(get_post_type_archive_link(get_post()->post_type)) ) {
                    $out .= '<li class="post-navigation-item archive-icon-link">';
                        $out .= '<a href="' . get_post_type_archive_link(get_post()->post_type) . '" class="archive-icon"></a>';
                    $out .= '</li>';
                }

                if ( $next_post ) {
                    $out .= '<li class="post-navigation-item next-post">';
                        $out .= '<div class="post-navigation-link">';
                            $out .= '<a href="' . get_permalink( $next_post ) . '">';
                                $out .= esc_html__('Next Post', 'cosmecos');
                            $out .= '</a>';
                        $out .= '</div>';
                        $out .= '<div class="post-navigation-block">';
                            $out .= '<div class="post-navigation-content">';
                                $out .= '<div class="post-navigation-title">';
                                    $out .= '<a href="' . get_permalink( $next_post ) . '">';
                                        if ( function_exists('wpm') ) {
                                            $out .= wpm_translate_string(wp_kses_post( $next_post->post_title ));
                                        } else {
                                            $out .= wp_kses_post( $next_post->post_title );
                                        }
                                    $out .= '</a>';
                                $out .= '</div>';
                            $next_categories = cosmecos_portfolio_categories_output($next_post->ID, true);
                            if ( !empty($next_categories) ) {
                                $out .= '<div class="post-navigation-categories">';
                                    $out .= sprintf('%s', $next_categories);
                                $out .= '</div>';
                            }
                            $out .= '</div>';
                            $thumbnail = get_the_post_thumbnail_url($next_post->ID, array(70, 70));
                            if ( !empty($thumbnail) ) {
                                $out .= '<a href="' . get_permalink( $next_post ) . '" class="post-navigation-image">';
                                    $out .= '<img src="' . esc_url($thumbnail) . '" alt="' . esc_attr($next_post->post_title) . '" />';
                                $out .= '</a>';
                            }
                        $out .= '</div>';
                    $out .= '</li>';
                } else {
                    $out .= '<li class="post-navigation-item next-post disabled"></li>';
                }
                $out .= '</ul>';
            $out .= '</nav>';
        }

        return $out;
    }
}

// Return URL to the current page
if (!function_exists('cosmecos_get_current_url')) {
    function cosmecos_get_current_url() {
        global $wp;
        return home_url(add_query_arg(array(), $wp->request));
    }
}

// Double Menu Walker
class Cosmecos_Double_Menu_Walker extends Walker_Nav_Menu {
    public function end_el( &$output, $item, $depth = 0, $args = null ) {
        if ( isset( $args->item_spacing ) && 'discard' === $args->item_spacing ) {
            $t = '';
            $n = '';
        } else {
            $t = "\t";
            $n = "\n";
        }
        $output .= "</li>{$n}";
        if ( !empty($args->center) && $item->ID == $args->center ) {
            $output .= '</ul>';
            $output .= cosmecos_get_logo_output(false, 'col-auto');

            $output .= '<ul' . ($args->menu_class ? ' class="' . esc_attr($args->menu_class) . '"' : '') . '>';
        }
    }
}

// Logo Output
if ( !function_exists('cosmecos_get_logo_output') ) {
    function cosmecos_get_logo_output($is_mobile = false, $additional_classes = '') {
        $classes = 'logo';
        $classes .= ( !empty($additional_classes) ? ' ' . esc_attr($additional_classes) : '' );
        $classes .= ( cosmecos_get_prefered_option('header_logo_retina') ? ' retina-logo' : ' non-retina-logo' );

        $logo_width = $logo_height = $logo_url = '';

        if (
            class_exists('RWMB_Loader') &&
            cosmecos_get_post_option('header_logo_customize') == 'on' &&
            !empty(cosmecos_get_post_option('header_logo_image'))
        ) {
            $logo_metadata = rwmb_meta( 'header_logo_image', array( 'size' => 'full' ) );
            $logo_width = (isset($logo_metadata['width']) ? intval($logo_metadata['width']) : '');
            $logo_height = (isset($logo_metadata['height']) ? intval($logo_metadata['height']) : '');
            $logo_url = $logo_metadata['url'];
            if ( cosmecos_get_post_option('header_logo_retina') == 1 ) {
                $logo_width = $logo_width / 2;
                $logo_height = $logo_height / 2;
            }
        } elseif (
            cosmecos_get_theme_mod('header_logo_customize') == 'on' &&
            !empty(cosmecos_get_theme_mod('header_logo_image')) &&
            cosmecos_get_post_option('header_logo_customize') != 'on'
        ) {
            $logo_metadata = wp_get_attachment_metadata(attachment_url_to_postid(cosmecos_get_theme_mod('header_logo_image')));
            $logo_width = (isset($logo_metadata['width']) ? $logo_metadata['width'] : 0);
            $logo_height = (isset($logo_metadata['height']) ? $logo_metadata['height'] : 0);
            $logo_url = cosmecos_get_theme_mod('header_logo_image');
            if ( cosmecos_get_theme_mod('header_logo_retina') == true ) {
                $logo_width = $logo_width / 2;
                $logo_height = $logo_height / 2;
            }
        }

        $output = '<div class="' . esc_attr($classes) . '">';
            $output .= '<a class="logo-link" href="' . esc_url(home_url('/')) . '">';
                if ( !empty($logo_url) ) {
                    if ( $is_mobile ) {
                        $logo_width = round($logo_width * 0.76);
                        $logo_height = round($logo_height * 0.76);
                    }
                    $output .= '<img width="' . esc_attr($logo_width) . '" height="' . esc_attr($logo_height) . '" src="' . esc_url($logo_url) . '" alt="' . get_bloginfo('name', 'display') . '" />';
                } else {
                    $output .= '<span class="logo-site-name">' . get_bloginfo('name', 'display') . '</span>';
                }
            $output .= '</a>';
        $output .= '</div>';

        return wp_kses(wp_unslash($output), array(
            'div'   => array(
                'class'     => true
            ),
            'span'  => array(
                'class'     => true
            ),
            'a'     => array(
                'class'     => true,
                'href'      => true
            ),
            'img'   => array(
                'class'     => true,
                'src'       => true,
                'width'     => true,
                'height'    => true,
                'alt'       => true
            )
        ));
    }
}