<?php
/*
 * Created by Artureanec
*/

# General
add_theme_support('title-tag');
add_theme_support('automatic-feed-links');
add_theme_support('post-formats', array('image', 'video', 'gallery', 'quote'));
add_theme_support('html5', array( 'comment-list', 'comment-form', 'search-form', 'gallery', 'caption' ) );

if( !isset( $content_width ) ) $content_width = 1170;

# ADD Localization Folder
add_action('after_setup_theme', 'cosmecos_pomo');
if (!function_exists('cosmecos_pomo')) {
    function cosmecos_pomo() {
        load_theme_textdomain('cosmecos', get_template_directory() . '/languages');
    }
}

require_once(get_template_directory() . '/core/helper-functions.php');
require_once(get_template_directory() . '/core/layout-functions.php');
require_once(get_template_directory() . '/core/init.php');

# Register CSS/JS
add_action('wp_enqueue_scripts', 'cosmecos_css_js');
if (!function_exists('cosmecos_css_js')) {
    function cosmecos_css_js() {
        # CSS
        wp_enqueue_style('cosmecos-style', get_template_directory_uri() . '/style.css', array('cosmecos-theme', 'cosmecos-woocommerce'), wp_get_theme()->get( 'Version' ) );
        wp_enqueue_style('cosmecos-theme', get_template_directory_uri() . '/css/theme.css');

        if (class_exists('WooCommerce')) {
            wp_enqueue_style('cosmecos-woocommerce', get_template_directory_uri() . '/css/woocommerce.css');
        }

        # JS
        wp_enqueue_script('jquery-cookie', get_template_directory_uri() . '/js/jquery.cookie.min.js', array('jquery'), false, true);
        wp_enqueue_script('cosmecos-theme', get_template_directory_uri() . '/js/theme.js', array('jquery', 'isotope'), false, true);
        wp_enqueue_script('owl-carousel', get_template_directory_uri() . '/js/owl.carousel.min.js', true, false, true);
        wp_enqueue_script('isotope', get_template_directory_uri() . '/js/isotope.min.js', array(), false, true );

        if (is_singular() && comments_open()) {
            wp_enqueue_script('comment-reply');
        }

        wp_localize_script('cosmecos-theme', 'cosmecos_ajaxurl',
            array(
                'url' => esc_url(admin_url('admin-ajax.php'))
            )
        );

        # Colors
        require_once(get_template_directory() . "/css/custom.php");

        global $cosmecos_custom_css;
        wp_add_inline_style('cosmecos-theme', $cosmecos_custom_css);
    }
}

# Register CSS/JS for Admin Settings
add_action('admin_enqueue_scripts', 'cosmecos_admin_css_js');
if (!function_exists('cosmecos_admin_css_js')) {
    function cosmecos_admin_css_js() {
        # CSS
        wp_enqueue_style('cosmecos-admin', get_template_directory_uri() . '/css/admin.css');
        # JS
        wp_enqueue_script('cosmecos-admin', get_template_directory_uri() . '/js/admin.js', array('jquery', 'jquery-ui-core', 'jquery-ui-sortable'), false, true);
    }
}



# WP Footer
add_action('wp_footer', 'cosmecos_wp_footer');
if (!function_exists('cosmecos_wp_footer')) {
    function cosmecos_wp_footer() {
        Cosmecos_Helper::getInstance()->echoFooter();
    }
}

# Register Menu
add_action('init', 'cosmecos_register_menu');
if (!function_exists('cosmecos_register_menu')) {
    function cosmecos_register_menu() {
        register_nav_menus(
            [
                'main'              => esc_html__('Main menu', 'cosmecos'),
                'top_bar_user_menu' => esc_html__('Top bar menu', 'cosmecos'),
                'footer_menu'       => esc_html__('Footer Menu', 'cosmecos'),
                'footer_add_menu'   => esc_html__('Footer Additional Menu', 'cosmecos')
            ]
        );
    }
}


# Register Sidebars
add_action('widgets_init', 'cosmecos_widgets_init');
if (!function_exists('cosmecos_widgets_init')) {
    function cosmecos_widgets_init() {
        register_sidebar(
            array(
                'name'          => esc_html__('Page Sidebar', 'cosmecos'),
                'id'            => 'sidebar',
                'description'   => esc_html__('Widgets in this area will be shown on all pages.', 'cosmecos'),
                'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-wrapper">',
                'after_widget'  => '</div></div>',
                'before_title'  => '<h4 class="widget-title"><span>',
                'after_title'   => '</span></h4>',
            )
        );

        register_sidebar(
            array(
                'name'          => esc_html__('Post Sidebar', 'cosmecos'),
                'id'            => 'sidebar-post',
                'description'   => esc_html__('Widgets in this area will be shown on all posts.', 'cosmecos'),
                'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-wrapper">',
                'after_widget'  => '</div></div>',
                'before_title'  => '<h4 class="widget-title"><span>',
                'after_title'   => '</span></h4>',
            )
        );

        register_sidebar(
            array(
                'name'          => esc_html__('Archive Sidebar', 'cosmecos'),
                'id'            => 'sidebar-archive',
                'description'   => esc_html__('Widgets in this area will be shown on all posts and archive pages.', 'cosmecos'),
                'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-wrapper">',
                'after_widget'  => '</div></div>',
                'before_title'  => '<h4 class="widget-title"><span>',
                'after_title'   => '</span></h4>',
            )
        );

        register_sidebar(
            array(
                'name'          => esc_html__('Side Panel Sidebar', 'cosmecos'),
                'id'            => 'sidebar-side',
                'description'   => esc_html__('Widgets in this area will be shown on side panel.', 'cosmecos'),
                'before_widget' => '<div id="%1$s" class="widget side-widget %2$s"><div class="widget-wrapper side-widget-wrapper">',
                'after_widget'  => '</div></div>',
                'before_title'  => '<h4 class="widget-title side-widget-title">',
                'after_title'   => '</h4>',
            )
        );

        register_sidebar(
            array(
                'name'          => esc_html__('Footer Sidebar (Style 1)', 'cosmecos'),
                'id'            => 'sidebar-footer-style1',
                'description'   => esc_html__('Widgets in this area will be shown on footer area.', 'cosmecos'),
                'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s"><div class="widget-wrapper footer-widget-wrapper">',
                'after_widget'  => '</div></div>',
                'before_title'  => '<h6 class="widget-title footer-widget-title">',
                'after_title'   => '</h6>',
            )
        );

        register_sidebar(
            array(
                'name'          => esc_html__('Footer Sidebar (Style 2)', 'cosmecos'),
                'id'            => 'sidebar-footer-style2',
                'description'   => esc_html__('Widgets in this area will be shown on footer area.', 'cosmecos'),
                'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s"><div class="widget-wrapper footer-widget-wrapper">',
                'after_widget'  => '</div></div>',
                'before_title'  => '<h6 class="widget-title footer-widget-title">',
                'after_title'   => '</h6>',
            )
        );

        register_sidebar(
            array(
                'name'          => esc_html__('Footer Sidebar (Style 3)', 'cosmecos'),
                'id'            => 'sidebar-footer-style3',
                'description'   => esc_html__('Widgets in this area will be shown on footer area.', 'cosmecos'),
                'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s"><div class="widget-wrapper footer-widget-wrapper">',
                'after_widget'  => '</div></div>',
                'before_title'  => '<h6 class="widget-title footer-widget-title">',
                'after_title'   => '</h6>',
            )
        );

        register_sidebar(
            array(
                'name'          => esc_html__('Footer Sidebar (Style 4)', 'cosmecos'),
                'id'            => 'sidebar-footer-style4',
                'description'   => esc_html__('Widgets in this area will be shown on footer area.', 'cosmecos'),
                'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s"><div class="widget-wrapper footer-widget-wrapper">',
                'after_widget'  => '</div></div>',
                'before_title'  => '<h6 class="widget-title footer-widget-title">',
                'after_title'   => '</h6>',
            )
        );

        register_sidebar(
            array(
                'name'          => esc_html__('Footer Sidebar (Style 5)', 'cosmecos'),
                'id'            => 'sidebar-footer-style5',
                'description'   => esc_html__('Widgets in this area will be shown on footer area.', 'cosmecos'),
                'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s"><div class="widget-wrapper footer-widget-wrapper">',
                'after_widget'  => '</div></div>',
                'before_title'  => '<h6 class="widget-title footer-widget-title">',
                'after_title'   => '</h6>',
            )
        );

        if (class_exists('WooCommerce')) {
            register_sidebar(
                array(
                    'name'          => esc_html__('Sidebar WooCommerce', 'cosmecos'),
                    'id'            => 'sidebar-woocommerce',
                    'description'   => esc_html__('Widgets in this area will be shown on Woocommerce Pages.', 'cosmecos'),
                    'before_widget' => '<div id="%1$s" class="widget wooсommerce-widget %2$s"><div class="widget-wrapper">',
                    'after_widget'  => '</div></div>',
                    'before_title'  => '<h4 class="widget-title"><span>',
                    'after_title'   => '</span></h4>',
                )
            );
        }
    }
}

// Init Custom Widgets
if ( function_exists('cosmecos_add_custom_widget') ) {
    cosmecos_add_custom_widget('cosmecos_contacts_widget');
    cosmecos_add_custom_widget('cosmecos_featured_posts_widget');
    cosmecos_add_custom_widget('cosmecos_banner_widget');
}

// Init Elementor for Custom Post Types
if (!function_exists('cosmecos_init_elementor_for_team_post_type')) {
    function cosmecos_init_elementor_for_team_post_type() {
        add_post_type_support('cosmecos-team', 'elementor');
    }
}
add_action('init', 'cosmecos_init_elementor_for_team_post_type');

if (!function_exists('cosmecos_init_elementor_for_portfolio_post_type')) {
    function cosmecos_init_elementor_for_portfolio_post_type() {
        add_post_type_support('cosmecos-portfolio', 'elementor');
    }
}
add_action('init', 'cosmecos_init_elementor_for_portfolio_post_type');

# WooCommerce
if (class_exists('WooCommerce')) {
    require_once( get_template_directory() . '/woocommerce/wooinit.php');
}

// Limit of Download Files Size //
add_filter( 'upload_size_limit', 'cosmecos_pbp_increase_upload' );
if (!function_exists('cosmecos_pbp_increase_upload')) {
    function cosmecos_pbp_increase_upload($bytes) {
        return 5242880; // 1 megabyte
    }
}

// Remove standard WP gallery styles
add_filter( 'use_default_gallery_style', '__return_false' );

// Register custom image sizes
if ( function_exists( 'add_theme_support' ) ) {
    add_theme_support( 'post-thumbnails' );
    set_post_thumbnail_size( 1170, 538, true );
}
if ( function_exists( 'add_image_size' ) ) {
    add_image_size( 'cosmecos_post_thumbnail_mobile', 535, 300, array('center', 'center') );
    add_image_size( 'cosmecos_post_thumbnail_tablet', 951, 438, array('center', 'center') );
    add_image_size( 'cosmecos_post_thumbnail_default', 830, 380, array('center', 'center') );
    add_image_size( 'cosmecos_post_thumbnail_full', 1170, 538, array('center', 'center') );

    add_image_size( 'cosmecos_post_grid_2_columns', 920, 780, array('center', 'center') );
    add_image_size( 'cosmecos_post_grid_3_columns', 600, 510, array('center', 'center') );
    add_image_size( 'cosmecos_post_grid_4_columns', 440, 374, array('center', 'center') );
    add_image_size( 'cosmecos_post_grid_5_columns', 344, 292, array('center', 'center') );
    add_image_size( 'cosmecos_post_grid_6_columns', 280, 238, array('center', 'center') );

    add_image_size( 'cosmecos_portfolio_thumbnail', 835, 518, array('center', 'center') );
    add_image_size( 'cosmecos_portfolio_grid_1_columns', 1200, 1200, array('center', 'center') );
    add_image_size( 'cosmecos_portfolio_grid_2_columns', 960, 960, array('center', 'center') );
    add_image_size( 'cosmecos_portfolio_grid_3_columns', 640, 640, array('center', 'center') );
    add_image_size( 'cosmecos_portfolio_grid_4_columns', 480, 480, array('center', 'center') );
    add_image_size( 'cosmecos_portfolio_grid_5_columns', 384, 384, array('center', 'center') );
    add_image_size( 'cosmecos_portfolio_grid_6_columns', 320, 320, array('center', 'center') );

    add_image_size( 'cosmecos_product_catalog_thumbnail', 545, 654, array('center', 'center') );
}
add_filter( 'image_size_names_choose', 'cosmecos_image_size_names' );
if ( !function_exists( 'cosmecos_image_size_names' ) ) {
    function cosmecos_image_size_names($sizes) {
        return array_merge($sizes, array(
            'cosmecos_post_thumbnail_default'    => esc_html__('Post Thumbnail (Default)', 'cosmecos'),
            'cosmecos_post_thumbnail_full'       => esc_html__('Post Thumbnail (Full)', 'cosmecos'),
        ));
    }
}

// Media Upload
if (!function_exists('cosmecos_enqueue_media')) {
    function cosmecos_enqueue_media() {
        wp_enqueue_media();
    }
}
add_action( 'admin_enqueue_scripts', 'cosmecos_enqueue_media' );

// Responsive video
add_filter('embed_oembed_html', 'cosmecos_wrap_oembed_video', 99, 4);
if (!function_exists('cosmecos_wrap_oembed_video')) {
    function cosmecos_wrap_oembed_video($html, $url, $attr, $post_id) {
        return '<div class="video-embed">' . $html . '</div>';
    }
}

// Custom Search form
add_filter('get_search_form', 'cosmecos_get_search_form', 10, 2);
if ( !function_exists('cosmecos_get_search_form') ) {
    function cosmecos_get_search_form($form, $args) {
        $search_rand = mt_rand(0, 999);
        $search_js = 'javascript:document.getElementById("search-' . esc_js($search_rand) . '").submit();';
        $placeholder = ( $args['aria_label'] == 'global' ? esc_attr__('Type Your Search...', 'cosmecos') : esc_attr__('Search', 'cosmecos') );

        $form = '<form name="search_form" method="get" action="' . esc_url(home_url('/')) . '" class="search-form" id="search-' . esc_attr($search_rand) . '">';
            $form .= '<span class="search-form-icon" onclick="' . esc_js($search_js) . '"></span>';
            $form .= '<input type="text" name="s" value="" placeholder="' . esc_attr($placeholder) . '" title="' . esc_attr__('Search', 'cosmecos') . '" class="search-form-field">';
        $form .= '</form>';

        return $form;
    }
}

// Customize WP Archive Widget
add_filter('get_archives_link', 'cosmecos_customize_archive_widget');
if ( !function_exists('cosmecos_customize_archive_widget') ) {
    function cosmecos_customize_archive_widget($output) {
        $output = str_replace('</a>&nbsp;(', '</a><span class="post-count">', $output);
        $output = str_replace(')', '</span>', $output);
        $output = str_replace('>(', '>', $output);

        return $output;
    }
}

// Customize WP Categories Widget
add_filter('wp_list_categories', 'cosmecos_customize_categories_widget', 10, 2);
if ( !function_exists('cosmecos_customize_categories_widget') ) {
    function cosmecos_customize_categories_widget($output, $args) {
        $args['use_desc_for_title'] = false;
        if ( !$args['hierarchical'] ) {
            $output = str_replace('</a> (', '</a><span class="post-count">', $output);
            $output = str_replace(')', '</span>', $output);
            $output = str_replace('>(', '>', $output);
        } else {
            $output = str_replace('"cat-item', '"cat-item cat-item-hierarchical', $output);
        }

        return $output;
    }
}

// Add 'Background color' button to Tiny MCE text editor
add_action( 'init', 'cosmecos_tiny_mce_background_color' );
if ( !function_exists('cosmecos_tiny_mce_background_color') ) {
    function cosmecos_tiny_mce_background_color() {
        add_filter('mce_buttons_2', 'cosmecos_tiny_mce_background_color_button', 999, 1);
    }
}
if ( !function_exists('cosmecos_tiny_mce_background_color_button') ) {
    function cosmecos_tiny_mce_background_color_button($buttons) {
        array_splice($buttons, 4, 0, 'backcolor');
        return $buttons;
    }
}

// Move Comment Message field in Comment form
add_filter( 'comment_form_fields', 'cosmacos_move_comment_fields' );
if ( !function_exists('cosmacos_move_comment_fields') ) {
    function cosmacos_move_comment_fields($fields) {
        if ( !function_exists('is_product') || !is_product() ) {
            $comment_field = $fields['comment'];
            $cookies_field = $fields['cookies'];
            unset($fields['comment']);
            unset($fields['cookies']);
            $fields['comment'] = $comment_field;
            $fields['cookies'] = $cookies_field;
        }
        return $fields;
    }
}

// WPForms Plugin Dropdown Menu Fix
if ( function_exists( 'wpforms') ) {
    add_action( 'wpforms_display_field_select', 'cosmecos_wpform_start_select_wrapper', 5, 1 );
    if ( !function_exists('cosmecos_wpform_start_select_wrapper') ) {
        function cosmecos_wpform_start_select_wrapper($field) {
            echo '<div class="select-wrap' . (!empty($field['size']) && isset($field['size']) ? ' wpforms-field-' . esc_attr($field['size']) : '') . '">';
        }
    }
    add_action( 'wpforms_display_field_select', 'cosmecos_wpform_finish_select_wrapper', 15 );
    if ( !function_exists('cosmecos_wpform_finish_select_wrapper') ) {
        function cosmecos_wpform_finish_select_wrapper() {
            echo '</div>';
        }
    }
}

// Custom Password Form
add_filter( 'the_password_form', 'cosmecos_password_form' );
if ( !function_exists('cosmecos_password_form') ) {
    function cosmecos_password_form() {
        global $post;
        $out = '<form action="' . esc_url(site_url('wp-login.php?action=postpass', 'login_post')) . '" class="post-password-form" method="post"><p>' . esc_html__('This content is password protected. To view it please enter your password below:', 'cosmecos') . '</p><p><label for="password"><input name="post_password" id="password" type="password" placeholder="' . esc_attr__('Password', 'cosmecos') . '" size="20" required /></label><button name="Submit">' . esc_html__('Enter', 'cosmecos') . '</button></p></form>';
        return $out;
    }
}

// Set Elementor Features Default Values
add_action( 'elementor/experiments/feature-registered', 'cosmecos_elementor_features_set_default', 10, 2 );
if ( !function_exists('cosmecos_elementor_features_set_default') ) {
    function cosmecos_elementor_features_set_default( Elementor\Core\Experiments\Manager $experiments_manager ) {
        $experiments_manager->set_feature_default_state('e_dom_optimization', 'inactive');
    }
}
